"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _OperationMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OperationModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OperationMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Off: _OperationMode.ValueType  # 0
    NarrowPulse: _OperationMode.ValueType  # 1
    BroadPulse: _OperationMode.ValueType  # 2
    CW: _OperationMode.ValueType  # 3

class OperationMode(_OperationMode, metaclass=_OperationModeEnumTypeWrapper): ...

Off: OperationMode.ValueType  # 0
NarrowPulse: OperationMode.ValueType  # 1
BroadPulse: OperationMode.ValueType  # 2
CW: OperationMode.ValueType  # 3
global___OperationMode = OperationMode

@typing.final
class PrimaGatingInfo(google.protobuf.message.Message):
    """Request messages for functions requiring multiple parameters"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_ON_TIME_FIELD_NUMBER: builtins.int
    MAX_ON_TIME_FIELD_NUMBER: builtins.int
    MIN_OFF_TIME_FACTOR_FIELD_NUMBER: builtins.int
    MAX_OFF_TIME_FACTOR_FIELD_NUMBER: builtins.int
    min_on_time: builtins.int
    max_on_time: builtins.int
    min_off_time_factor: builtins.int
    max_off_time_factor: builtins.int
    def __init__(
        self,
        *,
        min_on_time: builtins.int = ...,
        max_on_time: builtins.int = ...,
        min_off_time_factor: builtins.int = ...,
        max_off_time_factor: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["max_off_time_factor", b"max_off_time_factor", "max_on_time", b"max_on_time", "min_off_time_factor", b"min_off_time_factor", "min_on_time", b"min_on_time"]) -> None: ...

global___PrimaGatingInfo = PrimaGatingInfo

@typing.final
class TriggerLevelInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRG_MIN_LVL_FIELD_NUMBER: builtins.int
    TRG_MAX_LVL_FIELD_NUMBER: builtins.int
    TRG_LVL_RES_FIELD_NUMBER: builtins.int
    trg_min_lvl: builtins.int
    trg_max_lvl: builtins.int
    trg_lvl_res: builtins.int
    def __init__(
        self,
        *,
        trg_min_lvl: builtins.int = ...,
        trg_max_lvl: builtins.int = ...,
        trg_lvl_res: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trg_lvl_res", b"trg_lvl_res", "trg_max_lvl", b"trg_max_lvl", "trg_min_lvl", b"trg_min_lvl"]) -> None: ...

global___TriggerLevelInfo = TriggerLevelInfo

@typing.final
class TriggerInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRG_SRC_IDX_FIELD_NUMBER: builtins.int
    TRG_SRC_FIELD_NUMBER: builtins.int
    FREQUENCY_ENABLED_FIELD_NUMBER: builtins.int
    TRIG_LEVEL_ENABLED_FIELD_NUMBER: builtins.int
    trg_src_idx: builtins.int
    trg_src: builtins.str
    frequency_enabled: builtins.bool
    trig_level_enabled: builtins.bool
    def __init__(
        self,
        *,
        trg_src_idx: builtins.int = ...,
        trg_src: builtins.str = ...,
        frequency_enabled: builtins.bool = ...,
        trig_level_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["frequency_enabled", b"frequency_enabled", "trg_src", b"trg_src", "trg_src_idx", b"trg_src_idx", "trig_level_enabled", b"trig_level_enabled"]) -> None: ...

global___TriggerInfo = TriggerInfo

@typing.final
class PrimaModeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPER_MODE_IDX_FIELD_NUMBER: builtins.int
    OPER_MODE_FIELD_NUMBER: builtins.int
    oper_mode_idx: builtins.int
    oper_mode: builtins.str
    def __init__(
        self,
        *,
        oper_mode_idx: builtins.int = ...,
        oper_mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["oper_mode", b"oper_mode", "oper_mode_idx", b"oper_mode_idx"]) -> None: ...

global___PrimaModeInfo = PrimaModeInfo

@typing.final
class PrimaDevInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    FW_VERSION_FIELD_NUMBER: builtins.int
    WL_COUNT_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    device_type: builtins.str
    fw_version: builtins.str
    wl_count: builtins.int
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        device_type: builtins.str = ...,
        fw_version: builtins.str = ...,
        wl_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_id", b"device_id", "device_type", b"device_type", "fw_version", b"fw_version", "wl_count", b"wl_count"]) -> None: ...

global___PrimaDevInfo = PrimaDevInfo

@typing.final
class FwrRequestSupport(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREAMBLE_FIELD_NUMBER: builtins.int
    CALLING_SW_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    BUFFER_FIELD_NUMBER: builtins.int
    preamble: builtins.str
    calling_sw: builtins.str
    options: builtins.int
    buffer: builtins.int
    def __init__(
        self,
        *,
        preamble: builtins.str = ...,
        calling_sw: builtins.str = ...,
        options: builtins.int = ...,
        buffer: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["buffer", b"buffer", "calling_sw", b"calling_sw", "options", b"options", "preamble", b"preamble"]) -> None: ...

global___FwrRequestSupport = FwrRequestSupport

@typing.final
class UptimeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAIN_PWR_UP_FIELD_NUMBER: builtins.int
    ACTIVE_PWR_UP_FIELD_NUMBER: builtins.int
    SCALED_PWR_UP_FIELD_NUMBER: builtins.int
    main_pwr_up: builtins.int
    active_pwr_up: builtins.int
    scaled_pwr_up: builtins.int
    def __init__(
        self,
        *,
        main_pwr_up: builtins.int = ...,
        active_pwr_up: builtins.int = ...,
        scaled_pwr_up: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["active_pwr_up", b"active_pwr_up", "main_pwr_up", b"main_pwr_up", "scaled_pwr_up", b"scaled_pwr_up"]) -> None: ...

global___UptimeInfo = UptimeInfo

@typing.final
class ModuleInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SLOT_ID_FIELD_NUMBER: builtins.int
    IS_PRIMARY_FIELD_NUMBER: builtins.int
    IS_BACK_PLANE_FIELD_NUMBER: builtins.int
    HAS_UTC_FIELD_NUMBER: builtins.int
    slot_id: builtins.int
    is_primary: builtins.bool
    is_back_plane: builtins.bool
    has_UTC: builtins.bool
    def __init__(
        self,
        *,
        slot_id: builtins.int = ...,
        is_primary: builtins.bool = ...,
        is_back_plane: builtins.bool = ...,
        has_UTC: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["has_UTC", b"has_UTC", "is_back_plane", b"is_back_plane", "is_primary", b"is_primary", "slot_id", b"slot_id"]) -> None: ...

global___ModuleInfo = ModuleInfo

@typing.final
class FwrError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERR_CODE_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    SLOT_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    err_code: builtins.int
    phase: builtins.int
    location: builtins.int
    slot: builtins.int
    condition: builtins.str
    def __init__(
        self,
        *,
        err_code: builtins.int = ...,
        phase: builtins.int = ...,
        location: builtins.int = ...,
        slot: builtins.int = ...,
        condition: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["condition", b"condition", "err_code", b"err_code", "location", b"location", "phase", b"phase", "slot", b"slot"]) -> None: ...

global___FwrError = FwrError

@typing.final
class UsbDevice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRODUCTMODEL_FIELD_NUMBER: builtins.int
    SERIALNUMBER_FIELD_NUMBER: builtins.int
    ProductModel: builtins.str
    SerialNumber: builtins.str
    def __init__(
        self,
        *,
        ProductModel: builtins.str = ...,
        SerialNumber: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ProductModel", b"ProductModel", "SerialNumber", b"SerialNumber"]) -> None: ...

global___UsbDevice = UsbDevice

@typing.final
class Empty(google.protobuf.message.Message):
    """Common return types"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Empty = Empty

@typing.final
class String(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___String = String

@typing.final
class Bool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___Bool = Bool

@typing.final
class Int32(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___Int32 = Int32

@typing.final
class Uint32(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___Uint32 = Uint32

@typing.final
class DeviceIdx(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEV_IDX_FIELD_NUMBER: builtins.int
    dev_idx: builtins.int
    def __init__(
        self,
        *,
        dev_idx: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dev_idx", b"dev_idx"]) -> None: ...

global___DeviceIdx = DeviceIdx

@typing.final
class LibDecodeErrorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERR_STR_FIELD_NUMBER: builtins.int
    err_str: builtins.str
    def __init__(
        self,
        *,
        err_str: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["err_str", b"err_str"]) -> None: ...

global___LibDecodeErrorResponse = LibDecodeErrorResponse

@typing.final
class Version(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    def __init__(
        self,
        *,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["version", b"version"]) -> None: ...

global___Version = Version

@typing.final
class GetStrDescrByIdxRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEV_IDX_FIELD_NUMBER: builtins.int
    DESCR_IDX_FIELD_NUMBER: builtins.int
    dev_idx: builtins.int
    descr_idx: builtins.int
    def __init__(
        self,
        *,
        dev_idx: builtins.int = ...,
        descr_idx: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["descr_idx", b"descr_idx", "dev_idx", b"dev_idx"]) -> None: ...

global___GetStrDescrByIdxRequest = GetStrDescrByIdxRequest

@typing.final
class ErrPhaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERR_PHASE_FIELD_NUMBER: builtins.int
    err_phase: builtins.int
    def __init__(
        self,
        *,
        err_phase: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["err_phase", b"err_phase"]) -> None: ...

global___ErrPhaseRequest = ErrPhaseRequest

@typing.final
class FwrSetWorkingModeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEV_IDX_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    dev_idx: builtins.int
    mode: builtins.int
    def __init__(
        self,
        *,
        dev_idx: builtins.int = ...,
        mode: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dev_idx", b"dev_idx", "mode", b"mode"]) -> None: ...

global___FwrSetWorkingModeRequest = FwrSetWorkingModeRequest

@typing.final
class GetModuleMapRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEV_IDX_FIELD_NUMBER: builtins.int
    PERFORM_RESTART_FIELD_NUMBER: builtins.int
    dev_idx: builtins.int
    perform_restart: builtins.bool
    def __init__(
        self,
        *,
        dev_idx: builtins.int = ...,
        perform_restart: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dev_idx", b"dev_idx", "perform_restart", b"perform_restart"]) -> None: ...

global___GetModuleMapRequest = GetModuleMapRequest

@typing.final
class FrequencyLimitsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_FREQ_FIELD_NUMBER: builtins.int
    MAX_FREQ_FIELD_NUMBER: builtins.int
    min_freq: builtins.int
    max_freq: builtins.int
    def __init__(
        self,
        *,
        min_freq: builtins.int = ...,
        max_freq: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["max_freq", b"max_freq", "min_freq", b"min_freq"]) -> None: ...

global___FrequencyLimitsResponse = FrequencyLimitsResponse

@typing.final
class MapIdxRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEV_IDX_FIELD_NUMBER: builtins.int
    MAP_IDX_FIELD_NUMBER: builtins.int
    dev_idx: builtins.int
    map_idx: builtins.int
    def __init__(
        self,
        *,
        dev_idx: builtins.int = ...,
        map_idx: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dev_idx", b"dev_idx", "map_idx", b"map_idx"]) -> None: ...

global___MapIdxRequest = MapIdxRequest

@typing.final
class PriRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEV_IDX_FIELD_NUMBER: builtins.int
    SLOT_ID_FIELD_NUMBER: builtins.int
    dev_idx: builtins.int
    slot_id: builtins.int
    def __init__(
        self,
        *,
        dev_idx: builtins.int = ...,
        slot_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dev_idx", b"dev_idx", "slot_id", b"slot_id"]) -> None: ...

global___PriRequest = PriRequest

@typing.final
class SetFrequencyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRI_REQ_FIELD_NUMBER: builtins.int
    FREQUENCY_FIELD_NUMBER: builtins.int
    frequency: builtins.int
    @property
    def pri_req(self) -> global___PriRequest: ...
    def __init__(
        self,
        *,
        pri_req: global___PriRequest | None = ...,
        frequency: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pri_req", b"pri_req"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["frequency", b"frequency", "pri_req", b"pri_req"]) -> None: ...

global___SetFrequencyRequest = SetFrequencyRequest

@typing.final
class GatingEnabledRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRI_REQ_FIELD_NUMBER: builtins.int
    GATING_ENABLED_FIELD_NUMBER: builtins.int
    gating_enabled: builtins.bool
    @property
    def pri_req(self) -> global___PriRequest: ...
    def __init__(
        self,
        *,
        pri_req: global___PriRequest | None = ...,
        gating_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pri_req", b"pri_req"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["gating_enabled", b"gating_enabled", "pri_req", b"pri_req"]) -> None: ...

global___GatingEnabledRequest = GatingEnabledRequest

@typing.final
class WavelengthRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRI_REQ_FIELD_NUMBER: builtins.int
    WL_IDX_FIELD_NUMBER: builtins.int
    wl_idx: builtins.int
    @property
    def pri_req(self) -> global___PriRequest: ...
    def __init__(
        self,
        *,
        pri_req: global___PriRequest | None = ...,
        wl_idx: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pri_req", b"pri_req"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pri_req", b"pri_req", "wl_idx", b"wl_idx"]) -> None: ...

global___WavelengthRequest = WavelengthRequest

@typing.final
class SetIntensityRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WL_REQ_FIELD_NUMBER: builtins.int
    INTENSITY_FIELD_NUMBER: builtins.int
    intensity: builtins.int
    @property
    def wl_req(self) -> global___WavelengthRequest: ...
    def __init__(
        self,
        *,
        wl_req: global___WavelengthRequest | None = ...,
        intensity: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["wl_req", b"wl_req"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["intensity", b"intensity", "wl_req", b"wl_req"]) -> None: ...

global___SetIntensityRequest = SetIntensityRequest

@typing.final
class OperationModeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRI_REQ_FIELD_NUMBER: builtins.int
    OPER_MODE_ENUM_FIELD_NUMBER: builtins.int
    oper_mode_enum: global___OperationMode.ValueType
    @property
    def pri_req(self) -> global___PriRequest: ...
    def __init__(
        self,
        *,
        pri_req: global___PriRequest | None = ...,
        oper_mode_enum: global___OperationMode.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pri_req", b"pri_req"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["oper_mode_enum", b"oper_mode_enum", "pri_req", b"pri_req"]) -> None: ...

global___OperationModeRequest = OperationModeRequest

@typing.final
class OperationModeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: global___OperationMode.ValueType
    def __init__(
        self,
        *,
        value: global___OperationMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___OperationModeResponse = OperationModeResponse

@typing.final
class TriggerSourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRI_REQ_FIELD_NUMBER: builtins.int
    TRG_SRC_IDX_FIELD_NUMBER: builtins.int
    trg_src_idx: builtins.int
    @property
    def pri_req(self) -> global___PriRequest: ...
    def __init__(
        self,
        *,
        pri_req: global___PriRequest | None = ...,
        trg_src_idx: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pri_req", b"pri_req"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pri_req", b"pri_req", "trg_src_idx", b"trg_src_idx"]) -> None: ...

global___TriggerSourceRequest = TriggerSourceRequest

@typing.final
class TriggerLevelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRI_REQ_FIELD_NUMBER: builtins.int
    TRG_LVL_FIELD_NUMBER: builtins.int
    trg_lvl: builtins.int
    @property
    def pri_req(self) -> global___PriRequest: ...
    def __init__(
        self,
        *,
        pri_req: global___PriRequest | None = ...,
        trg_lvl: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pri_req", b"pri_req"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pri_req", b"pri_req", "trg_lvl", b"trg_lvl"]) -> None: ...

global___TriggerLevelRequest = TriggerLevelRequest

@typing.final
class GatingData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ON_TIME_FIELD_NUMBER: builtins.int
    OFF_TIME_FACTOR_FIELD_NUMBER: builtins.int
    on_time: builtins.int
    off_time_factor: builtins.int
    def __init__(
        self,
        *,
        on_time: builtins.int = ...,
        off_time_factor: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["off_time_factor", b"off_time_factor", "on_time", b"on_time"]) -> None: ...

global___GatingData = GatingData

@typing.final
class GatingDataRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRI_REQ_FIELD_NUMBER: builtins.int
    GATING_DATA_FIELD_NUMBER: builtins.int
    @property
    def pri_req(self) -> global___PriRequest: ...
    @property
    def gating_data(self) -> global___GatingData: ...
    def __init__(
        self,
        *,
        pri_req: global___PriRequest | None = ...,
        gating_data: global___GatingData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["gating_data", b"gating_data", "pri_req", b"pri_req"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["gating_data", b"gating_data", "pri_req", b"pri_req"]) -> None: ...

global___GatingDataRequest = GatingDataRequest

@typing.final
class HighImpedanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRI_REQ_FIELD_NUMBER: builtins.int
    HIGH_IMPEDANCE_FIELD_NUMBER: builtins.int
    high_impedance: builtins.bool
    @property
    def pri_req(self) -> global___PriRequest: ...
    def __init__(
        self,
        *,
        pri_req: global___PriRequest | None = ...,
        high_impedance: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pri_req", b"pri_req"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["high_impedance", b"high_impedance", "pri_req", b"pri_req"]) -> None: ...

global___HighImpedanceRequest = HighImpedanceRequest

@typing.final
class FwrRequestSupportRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEV_IDX_FIELD_NUMBER: builtins.int
    FWR_REQ_FIELD_NUMBER: builtins.int
    dev_idx: builtins.int
    @property
    def fwr_req(self) -> global___FwrRequestSupport: ...
    def __init__(
        self,
        *,
        dev_idx: builtins.int = ...,
        fwr_req: global___FwrRequestSupport | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fwr_req", b"fwr_req"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dev_idx", b"dev_idx", "fwr_req", b"fwr_req"]) -> None: ...

global___FwrRequestSupportRequest = FwrRequestSupportRequest

@typing.final
class Error(google.protobuf.message.Message):
    """NOTE: The following is part of tonic library by default
    Inspired from: https://github.com/hyperium/tonic/blob/78be69e92f297929d8f711d1927e4bdda8c324da/tonic-types/proto/status.proto#L37
    More details at: https://grpc.io/docs/guides/status-codes/
    Details on API Errors: https://google.aip.dev/193
    message Status {
     int32 code = 1;
     string message = 2;
     repeated google.protobuf.Any details = 3;
    }

    NOTE: For now, instead of passing the following error, will use builting Status with error message displayed from the original error
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Sepia2Error:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _Sepia2ErrorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Error._Sepia2Error.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SEPIA2_ERR_NO_ERROR: Error._Sepia2Error.ValueType  # 0
        """ "no error" - NOTE: This shouldn't be reachable code"""
        SEPIA2_ERR_FW_MEMORY_ALLOCATION_ERROR: Error._Sepia2Error.ValueType  # -1001
        """ "FW: memory allocation error" """
        SEPIA2_ERR_FW_CRC_ERROR_WHILE_CHECKING_SCM_828_MODULE: Error._Sepia2Error.ValueType  # -1002
        """ "FW: CRC error while checking SCM 828 module" """
        SEPIA2_ERR_FW_CRC_ERROR_WHILE_CHECKING_BACKPLANE: Error._Sepia2Error.ValueType  # -1003
        """ "FW: CRC error while checking backplane" """
        SEPIA2_ERR_FW_CRC_ERROR_WHILE_CHECKING_MODULE: Error._Sepia2Error.ValueType  # -1004
        """ "FW: CRC error while checking module" """
        SEPIA2_ERR_FW_MAPSIZE_ERROR: Error._Sepia2Error.ValueType  # -1005
        """ "FW: mapsize error" """
        SEPIA2_ERR_FW_UNKNOWN_ERROR_PHASE: Error._Sepia2Error.ValueType  # -1006
        """ "FW: unknown error phase" """
        SEPIA2_ERR_FW_INSUFFICIENT_FW_VERSION: Error._Sepia2Error.ValueType  # -1007
        """ "FW: insufficient FW version" """
        SEPIA2_ERR_FW_WRONG_WORKINGMODE: Error._Sepia2Error.ValueType  # -1008
        """ "FW: wrong workingmode" """
        SEPIA2_ERR_FW_ILLEGAL_MODULE_CHANGE: Error._Sepia2Error.ValueType  # -1111
        """ "FW: illegal module change" """
        SEPIA2_ERR_USB_WRONG_DRIVER_VERSION: Error._Sepia2Error.ValueType  # -2001
        """ "USB: wrong driver version" """
        SEPIA2_ERR_USB_OPEN_DEVICE_ERROR: Error._Sepia2Error.ValueType  # -2002
        """ "USB: open device error" """
        SEPIA2_ERR_USB_DEVICE_BUSY: Error._Sepia2Error.ValueType  # -2003
        """ "USB: device busy" """
        SEPIA2_ERR_USB_CLOSE_DEVICE_ERROR: Error._Sepia2Error.ValueType  # -2005
        """ "USB: close device error" """
        SEPIA2_ERR_USB_DEVICE_CHANGED: Error._Sepia2Error.ValueType  # -2006
        """ "USB: device changed" """
        SEPIA2_ERR_I2C_ADDRESS_ERROR: Error._Sepia2Error.ValueType  # -2010
        """ "I2C: address error" """
        SEPIA2_ERR_USB_DEVICE_INDEX_ERROR: Error._Sepia2Error.ValueType  # -2011
        """ "USB: device index error" """
        SEPIA2_ERR_I2C_ILLEGAL_MULTIPLEXER_PATH: Error._Sepia2Error.ValueType  # -2012
        """ "I2C: illegal multiplexer path" """
        SEPIA2_ERR_I2C_ILLEGAL_MULTIPLEXER_LEVEL: Error._Sepia2Error.ValueType  # -2013
        """ "I2C: illegal multiplexer level" """
        SEPIA2_ERR_I2C_ILLEGAL_SLOT_ID: Error._Sepia2Error.ValueType  # -2014
        """ "I2C: illegal slot id" """
        SEPIA2_ERR_FRAM_NO_UPTIME_COUNTER: Error._Sepia2Error.ValueType  # -2015
        """ "FRAM: no uptime counter" """
        SEPIA2_ERR_FRAM_BLOCKWRITE_ERROR: Error._Sepia2Error.ValueType  # -2020
        """ "FRAM: blockwrite error" """
        SEPIA2_ERR_FRAM_BLOCKREAD_ERROR: Error._Sepia2Error.ValueType  # -2021
        """ "FRAM: blockread error" """
        SEPIA2_ERR_FRAM_CRC_BLOCKCHECK_ERROR: Error._Sepia2Error.ValueType  # -2022
        """ "FRAM: CRC blockcheck error" """
        SEPIA2_ERR_RAM_BLOCK_ALLOCATION_ERROR: Error._Sepia2Error.ValueType  # -2023
        """ "RAM: block allocation error" """
        SEPIA2_ERR_RAM_SECURE_MEMORY_HANDLING_ERROR: Error._Sepia2Error.ValueType  # -2024
        """ "RAM: secure memory handling error" """
        SEPIA2_ERR_I2C_INITIALISING_COMMAND_EXECUTION_ERROR: Error._Sepia2Error.ValueType  # -2100
        """ "I2C: initialising command execution error" """
        SEPIA2_ERR_I2C_FETCHING_INITIALISING_COMMANDS_ERROR: Error._Sepia2Error.ValueType  # -2101
        """ "I2C: fetching initialising commands error" """
        SEPIA2_ERR_I2C_WRITING_INITIALISING_COMMANDS_ERROR: Error._Sepia2Error.ValueType  # -2102
        """ "I2C: writing initialising commands error" """
        SEPIA2_ERR_I2C_MODULE_CALIBRATING_ERROR: Error._Sepia2Error.ValueType  # -2200
        """ "I2C: module calibrating error" """
        SEPIA2_ERR_I2C_FETCHING_CALIBRATING_COMMANDS_ERROR: Error._Sepia2Error.ValueType  # -2201
        """ "I2C: fetching calibrating commands error" """
        SEPIA2_ERR_I2C_WRITING_CALIBRATING_COMMANDS_ERROR: Error._Sepia2Error.ValueType  # -2202
        """ "I2C: writing calibrating commands error" """
        SEPIA2_ERR_DCL_FILE_OPEN_ERROR: Error._Sepia2Error.ValueType  # -2301
        """ "DCL: file open error" """
        SEPIA2_ERR_DCL_WRONG_FILE_LENGTH: Error._Sepia2Error.ValueType  # -2302
        """ "DCL: wrong file length" """
        SEPIA2_ERR_DCL_FILE_READ_ERROR: Error._Sepia2Error.ValueType  # -2303
        """ "DCL: file read error" """
        SEPIA2_ERR_FRAM_IS_WRITE_PROTECTED: Error._Sepia2Error.ValueType  # -2304
        """ "FRAM: is write protected" """
        SEPIA2_ERR_DCL_FILE_SPECIFIES_DIFFERENT_MODULETYPE: Error._Sepia2Error.ValueType  # -2305
        """ "DCL: file specifies different moduletype" """
        SEPIA2_ERR_DCL_FILE_SPECIFIES_DIFFERENT_SERIAL_NUMBER: Error._Sepia2Error.ValueType  # -2306
        """ "DCL: file specifies different serial number" """
        SEPIA2_ERR_I2C_INVALID_ARGUMENT: Error._Sepia2Error.ValueType  # -3001
        """ "I2C: invalid argument" """
        SEPIA2_ERR_I2C_NO_ACKNOWLEDGE_ON_WRITE_ADRESSBYTE: Error._Sepia2Error.ValueType  # -3002
        """ "I2C: no acknowledge on write adressbyte" """
        SEPIA2_ERR_I2C_NO_ACKNOWLEDGE_ON_READ_ADRESSBYTE: Error._Sepia2Error.ValueType  # -3003
        """ "I2C: no acknowledge on read adressbyte" """
        SEPIA2_ERR_I2C_NO_ACKNOWLEDGE_ON_WRITE_DATABYTE: Error._Sepia2Error.ValueType  # -3004
        """ "I2C: no acknowledge on write databyte" """
        SEPIA2_ERR_I2C_READ_BACK_ERROR: Error._Sepia2Error.ValueType  # -3005
        """ "I2C: read back error" """
        SEPIA2_ERR_I2C_READ_ERROR: Error._Sepia2Error.ValueType  # -3006
        """ "I2C: read error" """
        SEPIA2_ERR_I2C_WRITE_ERROR: Error._Sepia2Error.ValueType  # -3007
        """ "I2C: write error" """
        SEPIA2_ERR_I_O_FILE_ERROR: Error._Sepia2Error.ValueType  # -3009
        """ "I/O: file error" """
        SEPIA2_ERR_I2C_MULTIPLEXER_ERROR: Error._Sepia2Error.ValueType  # -3014
        """ "I2C: multiplexer error" """
        SEPIA2_ERR_I2C_MULTIPLEXER_PATH_ERROR: Error._Sepia2Error.ValueType  # -3015
        """ "I2C: multiplexer path error" """
        SEPIA2_ERR_USB_INIT_FAILED: Error._Sepia2Error.ValueType  # -3200
        """ "USB: init failed" """
        SEPIA2_ERR_USB_INVALID_ARGUMENT: Error._Sepia2Error.ValueType  # -3201
        """ "USB: invalid argument" """
        SEPIA2_ERR_USB_DEVICE_STILL_OPEN: Error._Sepia2Error.ValueType  # -3202
        """ "USB: device still open" """
        SEPIA2_ERR_USB_NO_MEMORY: Error._Sepia2Error.ValueType  # -3203
        """ "USB: no memory" """
        SEPIA2_ERR_USB_OPEN_FAILED: Error._Sepia2Error.ValueType  # -3204
        """ "USB: open failed" """
        SEPIA2_ERR_USB_GET_DESCRIPTOR_FAILED: Error._Sepia2Error.ValueType  # -3205
        """ "USB: get descriptor failed" """
        SEPIA2_ERR_USB_INAPPROPRIATE_DEVICE: Error._Sepia2Error.ValueType  # -3206
        """ "USB: inappropriate device" """
        SEPIA2_ERR_USB_BUSY_DEVICE: Error._Sepia2Error.ValueType  # -3207
        """ "USB: busy device" """
        SEPIA2_ERR_USB_INVALID_HANDLE: Error._Sepia2Error.ValueType  # -3208
        """ "USB: invalid handle" """
        SEPIA2_ERR_USB_INVALID_DESCRIPTOR_BUFFER: Error._Sepia2Error.ValueType  # -3209
        """ "USB: invalid descriptor buffer" """
        SEPIA2_ERR_USB_IOCTRL_FAILED: Error._Sepia2Error.ValueType  # -3210
        """ "USB: IOCTRL failed" """
        SEPIA2_ERR_USB_VCMD_FAILED: Error._Sepia2Error.ValueType  # -3211
        """ "USB: vcmd failed" """
        SEPIA2_ERR_USB_NO_SUCH_PIPE: Error._Sepia2Error.ValueType  # -3212
        """ "USB: no such pipe" """
        SEPIA2_ERR_USB_REGISTER_NOTIFICATION_FAILED: Error._Sepia2Error.ValueType  # -3213
        """ "USB: register notification failed" """
        SEPIA2_ERR_USB_UNKNOWN_DEVICE: Error._Sepia2Error.ValueType  # -3214
        """ "USB: unknown device" """
        SEPIA2_ERR_USB_WRONG_DRIVER: Error._Sepia2Error.ValueType  # -3215
        """ "USB: wrong driver" """
        SEPIA2_ERR_USB_WINDOWS_ERROR: Error._Sepia2Error.ValueType  # -3216
        """ "USB: windows error" """
        SEPIA2_ERR_USB_DEVICE_NOT_OPEN: Error._Sepia2Error.ValueType  # -3217
        """ "USB: device not open" """
        SEPIA2_ERR_I2C_DEVICE_ERROR: Error._Sepia2Error.ValueType  # -3256
        """ "I2C: device error" """
        SEPIA2_ERR_LMP1_ADC_TABLES_NOT_FOUND: Error._Sepia2Error.ValueType  # -3501
        """ "LMP1: ADC tables not found" """
        SEPIA2_ERR_LMP1_ADC_OVERFLOW: Error._Sepia2Error.ValueType  # -3502
        """ "LMP1: ADC overflow" """
        SEPIA2_ERR_LMP1_ADC_UNDERFLOW: Error._Sepia2Error.ValueType  # -3503
        """ "LMP1: ADC underflow" """
        SEPIA2_ERR_SCM_VOLTAGE_LIMITS_TABLE_NOT_FOUND: Error._Sepia2Error.ValueType  # -4001
        """ "SCM: voltage limits table not found" """
        SEPIA2_ERR_SCM_VOLTAGE_SCALING_LIST_NOT_FOUND: Error._Sepia2Error.ValueType  # -4002
        """ "SCM: voltage scaling list not found" """
        SEPIA2_ERR_SCM_REPEATEDLY_MEASURED_VOLTAGE_FAILURE: Error._Sepia2Error.ValueType  # -4003
        """ "SCM: repeatedly measured voltage failure" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_0_VOLTAGE_TOO_LOW: Error._Sepia2Error.ValueType  # -4010
        """ "SCM: power supply line 0: voltage too low" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_1_VOLTAGE_TOO_LOW: Error._Sepia2Error.ValueType  # -4011
        """ "SCM: power supply line 1: voltage too low" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_2_VOLTAGE_TOO_LOW: Error._Sepia2Error.ValueType  # -4012
        """ "SCM: power supply line 2: voltage too low" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_3_VOLTAGE_TOO_LOW: Error._Sepia2Error.ValueType  # -4013
        """ "SCM: power supply line 3: voltage too low" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_4_VOLTAGE_TOO_LOW: Error._Sepia2Error.ValueType  # -4014
        """ "SCM: power supply line 4: voltage too low" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_5_VOLTAGE_TOO_LOW: Error._Sepia2Error.ValueType  # -4015
        """ "SCM: power supply line 5: voltage too low" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_6_VOLTAGE_TOO_LOW: Error._Sepia2Error.ValueType  # -4016
        """ "SCM: power supply line 6: voltage too low" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_7_VOLTAGE_TOO_LOW: Error._Sepia2Error.ValueType  # -4017
        """ "SCM: power supply line 7: voltage too low" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_0_VOLTAGE_TOO_HIGH: Error._Sepia2Error.ValueType  # -4020
        """ "SCM: power supply line 0: voltage too high" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_1_VOLTAGE_TOO_HIGH: Error._Sepia2Error.ValueType  # -4021
        """ "SCM: power supply line 1: voltage too high" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_2_VOLTAGE_TOO_HIGH: Error._Sepia2Error.ValueType  # -4022
        """ "SCM: power supply line 2: voltage too high" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_3_VOLTAGE_TOO_HIGH: Error._Sepia2Error.ValueType  # -4023
        """ "SCM: power supply line 3: voltage too high" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_4_VOLTAGE_TOO_HIGH: Error._Sepia2Error.ValueType  # -4024
        """ "SCM: power supply line 4: voltage too high" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_5_VOLTAGE_TOO_HIGH: Error._Sepia2Error.ValueType  # -4025
        """ "SCM: power supply line 5: voltage too high" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_6_VOLTAGE_TOO_HIGH: Error._Sepia2Error.ValueType  # -4026
        """ "SCM: power supply line 6: voltage too high" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_7_VOLTAGE_TOO_HIGH: Error._Sepia2Error.ValueType  # -4027
        """ "SCM: power supply line 7: voltage too high" """
        SEPIA2_ERR_SCM_POWER_SUPPLY_LASER_TURNING_OFF_VOLTAGE_TOO_HIGH: Error._Sepia2Error.ValueType  # -4030
        """ "SCM: power supply laser turning-off-voltage too high" """
        SEPIA2_ERR_SCM_INVALID_TEMPERATURE_TABLE_COUNT: Error._Sepia2Error.ValueType  # -4040
        """ "SCM: invalid temperature table count" """
        SEPIA2_ERR_SCM_TCONFG_TABLE_READ_FAILED: Error._Sepia2Error.ValueType  # -4041
        """ "SCM: tconfg table read failed" """
        SEPIA2_ERR_SCM_INVALID_NUMBER_OF_TABLE_ENTRIES: Error._Sepia2Error.ValueType  # -4042
        """ "SCM: invalid number of table entries" """
        SEPIA2_ERR_SCM_INVALID_TIMERTICK_VALUE: Error._Sepia2Error.ValueType  # -4043
        """ "SCM: invalid timertick value" """
        SEPIA2_ERR_SCM_INVALID_TEMPERATURE_VALUE_TABLE: Error._Sepia2Error.ValueType  # -4044
        """ "SCM: invalid temperature value table" """
        SEPIA2_ERR_SCM_INVALID_DAC_CONTROL_TABLE_A: Error._Sepia2Error.ValueType  # -4045
        """ "SCM: invalid DAC control table A" """
        SEPIA2_ERR_SCM_INVALID_DAC_CONTROL_TABLE_B: Error._Sepia2Error.ValueType  # -4046
        """ "SCM: invalid DAC control table B" """
        SEPIA2_ERR_SCM_TEMPERATURE_TABLE_READ_FAILED: Error._Sepia2Error.ValueType  # -4047
        """ "SCM: temperature table read failed" """
        SEPIA2_ERR_SOM_INT_OSCILLATOR_S_FREQ_LIST_NOT_FOUND: Error._Sepia2Error.ValueType  # -5001
        """ "SOM: int. oscillator's freq.-list not found" """
        SEPIA2_ERR_SOM_TRIGGER_MODE_LIST_NOT_FOUND: Error._Sepia2Error.ValueType  # -5002
        """ "SOM: trigger mode list not found" """
        SEPIA2_ERR_SOM_TRIGGER_LEVEL_NOT_FOUND: Error._Sepia2Error.ValueType  # -5003
        """ "SOM: trigger level not found" """
        SEPIA2_ERR_SOM_PREDIVIDER_PRETRIGGER_OR_TRIGGERMASK_NOT_FOUND: Error._Sepia2Error.ValueType  # -5004
        """ "SOM: predivider, pretrigger or triggermask not found" """
        SEPIA2_ERR_SOM_BURSTLENGTH_NOT_FOUND: Error._Sepia2Error.ValueType  # -5005
        """ "SOM: burstlength not found" """
        SEPIA2_ERR_SOM_OUTPUT_AND_SYNC_ENABLE_NOT_FOUND: Error._Sepia2Error.ValueType  # -5006
        """ "SOM: output and sync enable not found" """
        SEPIA2_ERR_SOM_TRIGGER_LEVEL_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -5007
        """ "SOM: trigger level out of bounds" """
        SEPIA2_ERR_SOM_ILLEGAL_FREQUENCY_TRIGGERMODE: Error._Sepia2Error.ValueType  # -5008
        """ "SOM: illegal frequency / triggermode" """
        SEPIA2_ERR_SOM_ILLEGAL_FREQUENCY_DIVIDER: Error._Sepia2Error.ValueType  # -5009
        """ "SOM: illegal frequency divider" """
        SEPIA2_ERR_SOM_ILLEGAL_PRESYNC: Error._Sepia2Error.ValueType  # -5010
        """ "SOM: illegal presync (greater than divider)" """
        SEPIA2_ERR_SOM_ILLEGAL_BURST_LENGTH: Error._Sepia2Error.ValueType  # -5011
        """ "SOM: illegal burst length (>/= 2^24 or < 0)" """
        SEPIA2_ERR_SOM_AUX_IO_CTRL_NOT_FOUND: Error._Sepia2Error.ValueType  # -5012
        """ "SOM: AUX I/O control data not found" """
        SEPIA2_ERR_SOM_ILLEGAL_AUX_OUT_CTRL: Error._Sepia2Error.ValueType  # -5013
        """ "SOM: illegal AUX output control data" """
        SEPIA2_ERR_SOM_ILLEGAL_AUX_IN_CTRL: Error._Sepia2Error.ValueType  # -5014
        """ "SOM: illegal AUX input control data" """
        SEPIA2_ERR_SOMD_INT_OSCILLATOR_S_FREQ_LIST_NOT_FOUND: Error._Sepia2Error.ValueType  # -5051
        """ "SOMD: int. oscillator's freq.-list not found" """
        SEPIA2_ERR_SOMD_TRIGGER_MODE_LIST_NOT_FOUND: Error._Sepia2Error.ValueType  # -5052
        """ "SOMD: trigger mode list not found" """
        SEPIA2_ERR_SOMD_TRIGGER_LEVEL_NOT_FOUND: Error._Sepia2Error.ValueType  # -5053
        """ "SOMD: trigger level not found" """
        SEPIA2_ERR_SOMD_PREDIVIDER_PRETRIGGER_OR_TRIGGERMASK_NOT_FOUND: Error._Sepia2Error.ValueType  # -5054
        """ "SOMD: predivider, pretrigger or triggermask not found" """
        SEPIA2_ERR_SOMD_BURSTLENGTH_NOT_FOUND: Error._Sepia2Error.ValueType  # -5055
        """ "SOMD: burstlength not found" """
        SEPIA2_ERR_SOMD_OUTPUT_AND_SYNC_ENABLE_NOT_FOUND: Error._Sepia2Error.ValueType  # -5056
        """ "SOMD: output and sync enable not found" """
        SEPIA2_ERR_SOMD_TRIGGER_LEVEL_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -5057
        """ "SOMD: trigger level out of bounds" """
        SEPIA2_ERR_SOMD_ILLEGAL_FREQUENCY_TRIGGERMODE: Error._Sepia2Error.ValueType  # -5058
        """ "SOMD: illegal frequency / triggermode" """
        SEPIA2_ERR_SOMD_ILLEGAL_FREQUENCY_DIVIDER: Error._Sepia2Error.ValueType  # -5059
        """ "SOMD: illegal frequency divider" """
        SEPIA2_ERR_SOMD_ILLEGAL_PRESYNC: Error._Sepia2Error.ValueType  # -5060
        """ "SOMD: illegal presync (greater than divider)" """
        SEPIA2_ERR_SOMD_ILLEGAL_BURST_LENGTH: Error._Sepia2Error.ValueType  # -5061
        """ "SOMD: illegal burst length (>/= 2^24 or < 0)" """
        SEPIA2_ERR_SOMD_AUX_IO_CTRL_NOT_FOUND: Error._Sepia2Error.ValueType  # -5062
        """ "SOMD: AUX I/O control data not found" """
        SEPIA2_ERR_SOMD_ILLEGAL_AUX_OUT_CTRL: Error._Sepia2Error.ValueType  # -5063
        """ "SOMD: illegal AUX output control data" """
        SEPIA2_ERR_SOMD_ILLEGAL_AUX_IN_CTRL: Error._Sepia2Error.ValueType  # -5064
        """ "SOMD: illegal AUX input control data" """
        SEPIA2_ERR_SOMD_ILLEGAL_OUT_MUX_CTRL: Error._Sepia2Error.ValueType  # -5071
        """ "SOMD: illegal output multiplexer control data" """
        SEPIA2_ERR_SOMD_OUTPUT_DELAY_DATA_NOT_FOUND: Error._Sepia2Error.ValueType  # -5072
        """ "SOMD: output delay data not found" """
        SEPIA2_ERR_SOMD_ILLEGAL_OUTPUT_DELAY_DATA: Error._Sepia2Error.ValueType  # -5073
        """ "SOMD: illegal output delay data" """
        SEPIA2_ERR_SOMD_DELAY_NOT_ALLOWED_IN_TRIGGER_MODE: Error._Sepia2Error.ValueType  # -5074
        """ "SOMD: delay not allowed in current trigger mode" """
        SEPIA2_ERR_SOMD_DEVICE_INITIALIZING: Error._Sepia2Error.ValueType  # -5075
        """ "SOMD: device initializing" """
        SEPIA2_ERR_SOMD_DEVICE_BUSY: Error._Sepia2Error.ValueType  # -5076
        """ "SOMD: device busy" """
        SEPIA2_ERR_SOMD_PLL_NOT_LOCKED: Error._Sepia2Error.ValueType  # -5077
        """ "SOMD: PLL not locked" """
        SEPIA2_ERR_SOMD_FW_UPDATE_FAILED: Error._Sepia2Error.ValueType  # -5080
        """ "SOMD: firmware update failed" """
        SEPIA2_ERR_SOMD_FW_CRC_CHECK_FAILED: Error._Sepia2Error.ValueType  # -5081
        """ "SOMD: firmware CRC check failed" """
        SEPIA2_ERR_SOMD_HW_TRIGGERSOURCE_ERROR: Error._Sepia2Error.ValueType  # -5101
        """ "SOMD HW: triggersource error" """
        SEPIA2_ERR_SOMD_HW_SYCHRONIZE_NOW_ERROR: Error._Sepia2Error.ValueType  # -5102
        """ "SOMD HW: sychronize now error" """
        SEPIA2_ERR_SOMD_HW_SYNC_RANGE_ERROR: Error._Sepia2Error.ValueType  # -5103
        """ "SOMD HW: SYNC range error" """
        SEPIA2_ERR_SOMD_HW_ILLEGAL_OUT_MUX_CTRL: Error._Sepia2Error.ValueType  # -5104
        """ "SOMD HW: illegal output multiplexer control data" """
        SEPIA2_ERR_SOMD_HW_SET_DELAY_ERROR: Error._Sepia2Error.ValueType  # -5105
        """ "SOMD HW: set delay error" """
        SEPIA2_ERR_SOMD_HW_AUX_IO_COMMAND_ERROR: Error._Sepia2Error.ValueType  # -5106
        """ "SOMD HW: AUX I/O command error" """
        SEPIA2_ERR_SOMD_HW_PLL_NOT_STABLE: Error._Sepia2Error.ValueType  # -5107
        """ "SOMD HW: PLL not stable" """
        SEPIA2_ERR_SOMD_HW_BURST_LENGTH_ERROR: Error._Sepia2Error.ValueType  # -5108
        """ "SOMD HW: burst length error" """
        SEPIA2_ERR_SOMD_HW_OUT_MUX_COMMAND_ERROR: Error._Sepia2Error.ValueType  # -5109
        """ "SOMD HW: output multiplexer command error" """
        SEPIA2_ERR_SOMD_HW_COARSE_DELAY_SET_ERROR: Error._Sepia2Error.ValueType  # -5110
        """ "SOMD HW: coarse delay set error" """
        SEPIA2_ERR_SOMD_HW_FINE_DELAY_SET_ERROR: Error._Sepia2Error.ValueType  # -5111
        """ "SOMD HW: fine delay set error" """
        SEPIA2_ERR_SOMD_HW_FW_EPROM_ERROR: Error._Sepia2Error.ValueType  # -5112
        """ "SOMD HW: firmware EPROM error" """
        SEPIA2_ERR_SOMD_HW_CRC_ERROR_ON_WRITING_FIRMWARE: Error._Sepia2Error.ValueType  # -5113
        """ "SOMD HW: CRC error on writing firmware" """
        SEPIA2_ERR_SOMD_HW_CALIBRATION_DATA_NOT_FOUND: Error._Sepia2Error.ValueType  # -5114
        """ "SOMD HW: calibration data not found" """
        SEPIA2_ERR_SOMD_HW_WRONG_EXTERNAL_FREQUENCY: Error._Sepia2Error.ValueType  # -5115
        """ "SOMD HW: wrong external frequency" """
        SEPIA2_ERR_SOMD_HW_EXTERNAL_FREQUENCY_NOT_STABLE: Error._Sepia2Error.ValueType  # -5116
        """ "SOMD HW: external frequency not stable" """
        SEPIA2_ERR_SLM_ILLEGAL_FREQUENCY_TRIGGERMODE: Error._Sepia2Error.ValueType  # -6001
        """ "SLM: illegal frequency / triggermode" """
        SEPIA2_ERR_SLM_ILLEGAL_INTENSITY: Error._Sepia2Error.ValueType  # -6002
        """ "SLM: illegal intensity (> 100% or < 0%)" """
        SEPIA2_ERR_SLM_ILLEGAL_HEAD_TYPE: Error._Sepia2Error.ValueType  # -6003
        """ "SLM: illegal head type" """
        SEPIA2_ERR_SML_ILLEGAL_INTENSITY: Error._Sepia2Error.ValueType  # -6501
        """ "SML: illegal intensity (> 100% or < 0%)" """
        SEPIA2_ERR_SML_POWER_SCALE_TABLES_NOT_FOUND: Error._Sepia2Error.ValueType  # -6502
        """ "SML: power scale tables not found" """
        SEPIA2_ERR_SML_ILLEGAL_HEAD_TYPE: Error._Sepia2Error.ValueType  # -6503
        """ "SML: illegal head type" """
        SEPIA2_ERR_VUV_VIR_SCALING_TABLES_NOT_FOUND: Error._Sepia2Error.ValueType  # -6511
        """ "VUV/VIR: scaling tables not found" """
        SEPIA2_ERR_VUV_VIR_DEVICE_TYPE_NOT_FOUND: Error._Sepia2Error.ValueType  # -6512
        """ "VUV/VIR: device type not found" """
        SEPIA2_ERR_VUV_VIR_ILLEGAL_TRIGGER_SOURCE_INDEX: Error._Sepia2Error.ValueType  # -6513
        """ "VUV/VIR: illegal trigger source index" """
        SEPIA2_ERR_VUV_VIR_ILLEGAL_FREQUENCY_DIVIDER_INDEX: Error._Sepia2Error.ValueType  # -6514
        """ "VUV/VIR: illegal frequency divider index" """
        SEPIA2_ERR_VUV_VIR_ILLEGAL_TRIGGER_LEVEL_VALUE: Error._Sepia2Error.ValueType  # -6515
        """ "VUV/VIR: illegal trigger level value" """
        SEPIA2_ERR_VUV_VIR_TRIGGER_DATA_NOT_FOUND: Error._Sepia2Error.ValueType  # -6516
        """ "VUV/VIR: trigger data not found" """
        SEPIA2_ERR_VUV_VIR_ILLEGAL_PUMP_REGISTER_READ_INDEX: Error._Sepia2Error.ValueType  # -6517
        """ "VUV/VIR: illegal pump register read index" """
        SEPIA2_ERR_VUV_VIR_ILLEGAL_PUMP_REGISTER_WRITE_INDEX: Error._Sepia2Error.ValueType  # -6518
        """ "VUV/VIR: illegal pump register write index" """
        SEPIA2_ERR_VUV_VIR_INTENSITY_DATA_NOT_FOUND: Error._Sepia2Error.ValueType  # -6519
        """ "VUV/VIR: intensity data not found" """
        SEPIA2_ERR_VUV_VIR_ILLEGAL_INTENSITY_DATA: Error._Sepia2Error.ValueType  # -6520
        """ "VUV/VIR: illegal intensity data" """
        SEPIA2_ERR_VUV_VIR_UNSUPPORTED_OPTION: Error._Sepia2Error.ValueType  # -6521
        """ "VUV/VIR: unsupported option" """
        SEPIA2_ERR_PRI_UI_CONSTANTS_TABLES_NOT_FOUND: Error._Sepia2Error.ValueType  # -6531
        """ "PRI: UI-constants tables not found" """
        SEPIA2_ERR_PRI_WAVELENGTHS_TABLE_NOT_FOUND: Error._Sepia2Error.ValueType  # -6532
        """ "PRI: wavelengths table not found" """
        SEPIA2_ERR_PRI_ILLEGAL_WAVELENGTH_INDEX: Error._Sepia2Error.ValueType  # -6533
        """ "PRI: illegal wavelength index" """
        SEPIA2_ERR_PRI_ERROR_ON_WRITING_WAVELENGTH_INDEX: Error._Sepia2Error.ValueType  # -6534
        """ "PRI: error on writing wavelength index" """
        SEPIA2_ERR_PRI_OPERATION_MODE_TEXTS_NOT_FOUND: Error._Sepia2Error.ValueType  # -6535
        """ "PRI: operation mode texts not found" """
        SEPIA2_ERR_PRI_OPERATION_MODE_COMMANDS_NOT_FOUND: Error._Sepia2Error.ValueType  # -6536
        """ "PRI: operation mode commands not found" """
        SEPIA2_ERR_PRI_ILLEGAL_OPERATION_MODE_INDEX: Error._Sepia2Error.ValueType  # -6537
        """ "PRI: illegal operation mode index" """
        SEPIA2_ERR_PRI_ERROR_ON_WRITING_OPERATION_MODE_INDEX: Error._Sepia2Error.ValueType  # -6538
        """ "PRI: error on writing operation mode index" """
        SEPIA2_ERR_PRI_TRIGGER_SOURCE_TEXTS_NOT_FOUND: Error._Sepia2Error.ValueType  # -6539
        """ "PRI: trigger source texts not found" """
        SEPIA2_ERR_PRI_TRIGGER_SOURCE_COMMANDS_NOT_FOUND: Error._Sepia2Error.ValueType  # -6540
        """ "PRI: trigger source commands not found" """
        SEPIA2_ERR_PRI_ILLEGAL_TRIGGER_SOURCE_INDEX: Error._Sepia2Error.ValueType  # -6541
        """ "PRI: illegal trigger source index" """
        SEPIA2_ERR_PRI_ERROR_ON_WRITING_TRIGGER_SOURCE_INDEX: Error._Sepia2Error.ValueType  # -6542
        """ "PRI: error on writing trigger source index" """
        SEPIA2_ERR_PRI_ILLEGAL_TRIGGER_LEVEL: Error._Sepia2Error.ValueType  # -6543
        """ "PRI: illegal trigger level" """
        SEPIA2_ERR_PRI_ERROR_ON_WRITING_TRIGGER_LEVEL: Error._Sepia2Error.ValueType  # -6544
        """ "PRI: error on writing trigger level" """
        SEPIA2_ERR_PRI_ILLEGAL_INTENSITY_DATA: Error._Sepia2Error.ValueType  # -6545
        """ "PRI: illegal intensity data" """
        SEPIA2_ERR_PRI_ERROR_ON_WRITING_INTENSITY_DATA: Error._Sepia2Error.ValueType  # -6546
        """ "PRI: error on writing intensity data" """
        SEPIA2_ERR_PRI_ILLEGAL_FREQUENCY_DATA: Error._Sepia2Error.ValueType  # -6547
        """ "PRI: illegal frequency data" """
        SEPIA2_ERR_PRI_ERROR_ON_WRITING_FREQUENCY_DATA: Error._Sepia2Error.ValueType  # -6548
        """ "PRI: error on writing frequency data" """
        SEPIA2_ERR_PRI_ILLEGAL_GATING_DATA: Error._Sepia2Error.ValueType  # -6549
        """ "PRI: illegal gating data" """
        SEPIA2_ERR_PRI_ERROR_ON_WRITING_GATING_DATA: Error._Sepia2Error.ValueType  # -6550
        """ "PRI: error on writing gating data" """
        SEPIA2_ERR_SWM_CALTABLES_NOT_FOUND: Error._Sepia2Error.ValueType  # -6701
        """ "SWM: calibration tables not found" """
        SEPIA2_ERR_SWM_ILLEGAL_CURVE_INDEX: Error._Sepia2Error.ValueType  # -6702
        """ "SWM: illegal curve index" """
        SEPIA2_ERR_SWM_ILLEGAL_TIMEBASE_RANGE_INDEX: Error._Sepia2Error.ValueType  # -6703
        """ "SWM: illegal timebase range index" """
        SEPIA2_ERR_SWM_ILLEGAL_PULSE_AMPLITUDE: Error._Sepia2Error.ValueType  # -6704
        """ "SWM: illegal pulse amplitude" """
        SEPIA2_ERR_SWM_ILLEGAL_RAMP_SLEW_RATE: Error._Sepia2Error.ValueType  # -6705
        """ "SWM: illegal ramp slew rate" """
        SEPIA2_ERR_SWM_ILLEGAL_PULSE_START_DELAY: Error._Sepia2Error.ValueType  # -6706
        """ "SWM: illegal pulse start delay" """
        SEPIA2_ERR_SWM_ILLEGAL_RAMP_START_DELAY: Error._Sepia2Error.ValueType  # -6707
        """ "SWM: illegal ramp start delay" """
        SEPIA2_ERR_SWM_ILLEGAL_WAVE_STOP_DELAY: Error._Sepia2Error.ValueType  # -6708
        """ "SWM: illegal wave stop delay" """
        SEPIA2_ERR_SWM_ILLEGAL_TABLENAME: Error._Sepia2Error.ValueType  # -6709
        """ "SWM: illegal tablename" """
        SEPIA2_ERR_SWM_ILLEGAL_TABLE_INDEX: Error._Sepia2Error.ValueType  # -6710
        """ "SWM: illegal table index" """
        SEPIA2_ERR_SWM_ILLEGAL_TABLE_FIELD: Error._Sepia2Error.ValueType  # -6711
        """ "SWM: illegal table field" """
        SEPIA2_ERR_SWM_EXT_ATTENUATION_NOT_FOUND: Error._Sepia2Error.ValueType  # -6712
        """ "SWM: ext. attenuation not found" """
        SEPIA2_ERR_SWM_ILLEGAL_ATTENUATION_VALUE: Error._Sepia2Error.ValueType  # -6713
        """ "SWM: illegal attenuation value" """
        SEPIA2_ERR_VCL_UI_CONSTANTS_NOT_FOUND: Error._Sepia2Error.ValueType  # -6751
        """ "VCL: UI-constants not found" """
        SEPIA2_ERR_VCL_TEMPERATURE_CALTABLE_NOT_FOUND: Error._Sepia2Error.ValueType  # -6752
        """ "VCL: temperature calibration table not found" """
        SEPIA2_ERR_VCL_BIAS_VOLTAGE_CALTABLE_NOT_FOUND: Error._Sepia2Error.ValueType  # -6753
        """ "VCL: bias voltage calibration table not found" """
        SEPIA2_ERR_VCL_ILLEGAL_TEMPERATURE: Error._Sepia2Error.ValueType  # -6754
        """ "VCL: illegal temperature" """
        SEPIA2_ERR_VCL_ILLEGAL_BIAS_VOLTAGE: Error._Sepia2Error.ValueType  # -6755
        """ "VCL: illegal bias voltage" """
        SEPIA2_ERR_SPM_ILLEGAL_INPUT_VALUE: Error._Sepia2Error.ValueType  # -7001
        """ "SPM: illegal input value" """
        SEPIA2_ERR_SPM_VALUE_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -7006
        """ "SPM: value out of bounds" """
        SEPIA2_ERR_SPM_FW_OUT_OF_MEMORY: Error._Sepia2Error.ValueType  # -7011
        """ "SPM FW: out of memory" """
        SEPIA2_ERR_SPM_FW_UPDATE_FAILED: Error._Sepia2Error.ValueType  # -7013
        """ "SPM FW: update failed" """
        SEPIA2_ERR_SPM_FW_CRC_CHECK_FAILED: Error._Sepia2Error.ValueType  # -7014
        """ "SPM FW: CRC check failed" """
        SEPIA2_ERR_SPM_FW_FLASH_DELETION_FAILED: Error._Sepia2Error.ValueType  # -7015
        """ "SPM FW: flash deletion failed" """
        SEPIA2_ERR_SPM_FW_FUNCTION_NOT_IMPLEMENTED: Error._Sepia2Error.ValueType  # -7017
        """ "SPM FW: function not implemented" """
        SEPIA2_ERR_SPM_FW_FILE_OPEN_ERROR: Error._Sepia2Error.ValueType  # -7021
        """ "SPM FW: file open error" """
        SEPIA2_ERR_SPM_FW_FILE_READ_ERROR: Error._Sepia2Error.ValueType  # -7022
        """ "SPM FW: file read error" """
        SEPIA2_ERR_SSM_SCALING_TABLES_NOT_FOUND: Error._Sepia2Error.ValueType  # -7051
        """ "SSM: scaling tables not found" """
        SEPIA2_ERR_SSM_ILLEGAL_TRIGGER_MODE: Error._Sepia2Error.ValueType  # -7052
        """ "SSM: illegal trigger mode" """
        SEPIA2_ERR_SSM_ILLEGAL_TRIGGER_LEVEL_VALUE: Error._Sepia2Error.ValueType  # -7053
        """ "SSM: illegal trigger level value" """
        SEPIA2_ERR_SSM_ILLEGAL_CORRECTION_VALUE: Error._Sepia2Error.ValueType  # -7054
        """ "SSM: illegal correction value" """
        SEPIA2_ERR_SSM_TRIGGER_DATA_NOT_FOUND: Error._Sepia2Error.ValueType  # -7055
        """ "SSM: trigger data not found" """
        SEPIA2_ERR_SSM_CORRECTION_DATA_COMMAND_NOT_FOUND: Error._Sepia2Error.ValueType  # -7056
        """ "SSM: correction data command not found" """
        SEPIA2_ERR_SWS_SCALING_TABLES_NOT_FOUND: Error._Sepia2Error.ValueType  # -7101
        """ "SWS: scaling tables not found" """
        SEPIA2_ERR_SWS_ILLEGAL_HW_MODULETYPE: Error._Sepia2Error.ValueType  # -7102
        """ "SWS: illegal HW moduletype" """
        SEPIA2_ERR_SWS_MODULE_NOT_FUNCTIONAL: Error._Sepia2Error.ValueType  # -7103
        """ "SWS: module not functional" """
        SEPIA2_ERR_SWS_ILLEGAL_CENTER_WAVELENGTH: Error._Sepia2Error.ValueType  # -7104
        """ "SWS: illegal center wavelength" """
        SEPIA2_ERR_SWS_ILLEGAL_BANDWIDTH: Error._Sepia2Error.ValueType  # -7105
        """ "SWS: illegal bandwidth" """
        SEPIA2_ERR_SWS_VALUE_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -7106
        """ "SWS: value out of bounds" """
        SEPIA2_ERR_SWS_MODULE_BUSY: Error._Sepia2Error.ValueType  # -7107
        """ "SWS: module busy" """
        SEPIA2_ERR_SWS_FW_WRONG_COMPONENT_ANSWERING: Error._Sepia2Error.ValueType  # -7109
        """ "SWS FW: wrong component answering" """
        SEPIA2_ERR_SWS_FW_UNKNOWN_HW_MODULETYPE: Error._Sepia2Error.ValueType  # -7110
        """ "SWS FW: unknown HW moduletype" """
        SEPIA2_ERR_SWS_FW_OUT_OF_MEMORY: Error._Sepia2Error.ValueType  # -7111
        """ "SWS FW: out of memory" """
        SEPIA2_ERR_SWS_FW_VERSION_CONFLICT: Error._Sepia2Error.ValueType  # -7112
        """ "SWS FW: version conflict" """
        SEPIA2_ERR_SWS_FW_UPDATE_FAILED: Error._Sepia2Error.ValueType  # -7113
        """ "SWS FW: update failed" """
        SEPIA2_ERR_SWS_FW_CRC_CHECK_FAILED: Error._Sepia2Error.ValueType  # -7114
        """ "SWS FW: CRC check failed" """
        SEPIA2_ERR_SWS_FW_ERROR_ON_FLASH_DELETION: Error._Sepia2Error.ValueType  # -7115
        """ "SWS FW: error on flash deletion" """
        SEPIA2_ERR_SWS_FW_CALIBRATION_MODE_ERROR: Error._Sepia2Error.ValueType  # -7116
        """ "SWS FW: calibration mode error" """
        SEPIA2_ERR_SWS_FW_FUNCTION_NOT_IMPLEMENTED: Error._Sepia2Error.ValueType  # -7117
        """ "SWS FW: function not implemented" """
        SEPIA2_ERR_SWS_FW_WRONG_CALTABLE_ENTRY: Error._Sepia2Error.ValueType  # -7118
        """ "SWS FW: wrong calibration table entry" """
        SEPIA2_ERR_SWS_FW_INSUFFICIENT_CALTABLE_SIZE: Error._Sepia2Error.ValueType  # -7119
        """ "SWS FW: insufficient calibration table size" """
        SEPIA2_ERR_SWS_FW_FILE_OPEN_ERROR: Error._Sepia2Error.ValueType  # -7151
        """ "SWS FW: file open error" """
        SEPIA2_ERR_SWS_FW_FILE_READ_ERROR: Error._Sepia2Error.ValueType  # -7152
        """ "SWS FW: file read error" """
        SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_INIT_TIMEOUT: Error._Sepia2Error.ValueType  # -7201
        """ "SWS HW: module 0, all motors: init timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_PLAUSI_CHECK: Error._Sepia2Error.ValueType  # -7202
        """ "SWS HW: module 0, all motors: plausi check" """
        SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_DAC_SET_CURRENT: Error._Sepia2Error.ValueType  # -7203
        """ "SWS HW: module 0, all motors: DAC set current" """
        SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_TIMEOUT: Error._Sepia2Error.ValueType  # -7204
        """ "SWS HW: module 0, all motors: timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_FLASH_WRITE_ERROR: Error._Sepia2Error.ValueType  # -7205
        """ "SWS HW: module 0, all motors: flash write error" """
        SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -7206
        """ "SWS HW: module 0, all motors: out of bounds" """
        SEPIA2_ERR_SWS_HW_MODULE_0_I2C_FAILURE: Error._Sepia2Error.ValueType  # -7207
        """ "SWS HW: module 0: I2C failure" """
        SEPIA2_ERR_SWS_HW_MODULE_0_INIT_FAILURE: Error._Sepia2Error.ValueType  # -7208
        """ "SWS HW: module 0: init failure" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_DATA_NOT_FOUND: Error._Sepia2Error.ValueType  # -7210
        """ "SWS HW: module 0, motor 1: data not found" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_INIT_TIMEOUT: Error._Sepia2Error.ValueType  # -7211
        """ "SWS HW: module 0, motor 1: init timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_PLAUSI_CHECK: Error._Sepia2Error.ValueType  # -7212
        """ "SWS HW: module 0, motor 1: plausi check" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_DAC_SET_CURRENT: Error._Sepia2Error.ValueType  # -7213
        """ "SWS HW: module 0, motor 1: DAC set current" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_TIMEOUT: Error._Sepia2Error.ValueType  # -7214
        """ "SWS HW: module 0, motor 1: timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_FLASH_WRITE_ERROR: Error._Sepia2Error.ValueType  # -7215
        """ "SWS HW: module 0, motor 1: flash write error" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -7216
        """ "SWS HW: module 0, motor 1: out of bounds" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_DATA_NOT_FOUND: Error._Sepia2Error.ValueType  # -7220
        """ "SWS HW: module 0, motor 2: data not found" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_INIT_TIMEOUT: Error._Sepia2Error.ValueType  # -7221
        """ "SWS HW: module 0, motor 2: init timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_PLAUSI_CHECK: Error._Sepia2Error.ValueType  # -7222
        """ "SWS HW: module 0, motor 2: plausi check" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_DAC_SET_CURRENT: Error._Sepia2Error.ValueType  # -7223
        """ "SWS HW: module 0, motor 2: DAC set current" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_TIMEOUT: Error._Sepia2Error.ValueType  # -7224
        """ "SWS HW: module 0, motor 2: timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_FLASH_WRITE_ERROR: Error._Sepia2Error.ValueType  # -7225
        """ "SWS HW: module 0, motor 2: flash write error" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -7226
        """ "SWS HW: module 0, motor 2: out of bounds" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_DATA_NOT_FOUND: Error._Sepia2Error.ValueType  # -7230
        """ "SWS HW: module 0, motor 3: data not found" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_INIT_TIMEOUT: Error._Sepia2Error.ValueType  # -7231
        """ "SWS HW: module 0, motor 3: init timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_PLAUSI_CHECK: Error._Sepia2Error.ValueType  # -7232
        """ "SWS HW: module 0, motor 3: plausi check" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_DAC_SET_CURRENT: Error._Sepia2Error.ValueType  # -7233
        """ "SWS HW: module 0, motor 3: DAC set current" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_TIMEOUT: Error._Sepia2Error.ValueType  # -7234
        """ "SWS HW: module 0, motor 3: timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_FLASH_WRITE_ERROR: Error._Sepia2Error.ValueType  # -7235
        """ "SWS HW: module 0, motor 3: flash write error" """
        SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -7236
        """ "SWS HW: module 0, motor 3: out of bounds" """
        SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_INIT_TIMEOUT: Error._Sepia2Error.ValueType  # -7301
        """ "SWS HW: module 1, all motors: init timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_PLAUSI_CHECK: Error._Sepia2Error.ValueType  # -7302
        """ "SWS HW: module 1, all motors: plausi check" """
        SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_DAC_SET_CURRENT: Error._Sepia2Error.ValueType  # -7303
        """ "SWS HW: module 1, all motors: DAC set current" """
        SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_TIMEOUT: Error._Sepia2Error.ValueType  # -7304
        """ "SWS HW: module 1, all motors: timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_FLASH_WRITE_ERROR: Error._Sepia2Error.ValueType  # -7305
        """ "SWS HW: module 1, all motors: flash write error" """
        SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -7306
        """ "SWS HW: module 1, all motors: out of bounds" """
        SEPIA2_ERR_SWS_HW_MODULE_1_I2C_FAILURE: Error._Sepia2Error.ValueType  # -7307
        """ "SWS HW: module 1: I2C failure" """
        SEPIA2_ERR_SWS_HW_MODULE_1_INIT_FAILURE: Error._Sepia2Error.ValueType  # -7308
        """ "SWS HW: module 1: init failure" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_DATA_NOT_FOUND: Error._Sepia2Error.ValueType  # -7310
        """ "SWS HW: module 1, motor 1: data not found" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_INIT_TIMEOUT: Error._Sepia2Error.ValueType  # -7311
        """ "SWS HW: module 1, motor 1: init timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_PLAUSI_CHECK: Error._Sepia2Error.ValueType  # -7312
        """ "SWS HW: module 1, motor 1: plausi check" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_DAC_SET_CURRENT: Error._Sepia2Error.ValueType  # -7313
        """ "SWS HW: module 1, motor 1: DAC set current" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_TIMEOUT: Error._Sepia2Error.ValueType  # -7314
        """ "SWS HW: module 1, motor 1: timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_FLASH_WRITE_ERROR: Error._Sepia2Error.ValueType  # -7315
        """ "SWS HW: module 1, motor 1: flash write error" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -7316
        """ "SWS HW: module 1, motor 1: out of bounds" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_DATA_NOT_FOUND: Error._Sepia2Error.ValueType  # -7320
        """ "SWS HW: module 1, motor 2: data not found" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_INIT_TIMEOUT: Error._Sepia2Error.ValueType  # -7321
        """ "SWS HW: module 1, motor 2: init timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_PLAUSI_CHECK: Error._Sepia2Error.ValueType  # -7322
        """ "SWS HW: module 1, motor 2: plausi check" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_DAC_SET_CURRENT: Error._Sepia2Error.ValueType  # -7323
        """ "SWS HW: module 1, motor 2: DAC set current" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_TIMEOUT: Error._Sepia2Error.ValueType  # -7324
        """ "SWS HW: module 1, motor 2: timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_FLASH_WRITE_ERROR: Error._Sepia2Error.ValueType  # -7325
        """ "SWS HW: module 1, motor 2: flash write error" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -7326
        """ "SWS HW: module 1, motor 2: out of bounds" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_DATA_NOT_FOUND: Error._Sepia2Error.ValueType  # -7330
        """ "SWS HW: module 1, motor 3: data not found" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_INIT_TIMEOUT: Error._Sepia2Error.ValueType  # -7331
        """ "SWS HW: module 1, motor 3: init timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_PLAUSI_CHECK: Error._Sepia2Error.ValueType  # -7332
        """ "SWS HW: module 1, motor 3: plausi check" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_DAC_SET_CURRENT: Error._Sepia2Error.ValueType  # -7333
        """ "SWS HW: module 1, motor 3: DAC set current" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_TIMEOUT: Error._Sepia2Error.ValueType  # -7334
        """ "SWS HW: module 1, motor 3: timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_FLASH_WRITE_ERROR: Error._Sepia2Error.ValueType  # -7335
        """ "SWS HW: module 1, motor 3: flash write error" """
        SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -7336
        """ "SWS HW: module 1, motor 3: out of bounds" """
        SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_INIT_TIMEOUT: Error._Sepia2Error.ValueType  # -7401
        """ "SWS HW: module 2, all motors: init timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_PLAUSI_CHECK: Error._Sepia2Error.ValueType  # -7402
        """ "SWS HW: module 2, all motors: plausi check" """
        SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_DAC_SET_CURRENT: Error._Sepia2Error.ValueType  # -7403
        """ "SWS HW: module 2, all motors: DAC set current" """
        SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_TIMEOUT: Error._Sepia2Error.ValueType  # -7404
        """ "SWS HW: module 2, all motors: timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_FLASH_WRITE_ERROR: Error._Sepia2Error.ValueType  # -7405
        """ "SWS HW: module 2, all motors: flash write error" """
        SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -7406
        """ "SWS HW: module 2, all motors: out of bounds" """
        SEPIA2_ERR_SWS_HW_MODULE_2_I2C_FAILURE: Error._Sepia2Error.ValueType  # -7407
        """ "SWS HW: module 2: I2C failure" """
        SEPIA2_ERR_SWS_HW_MODULE_2_INIT_FAILURE: Error._Sepia2Error.ValueType  # -7408
        """ "SWS HW: module 2: init failure" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_DATA_NOT_FOUND: Error._Sepia2Error.ValueType  # -7410
        """ "SWS HW: module 2, motor 1: data not found" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_INIT_TIMEOUT: Error._Sepia2Error.ValueType  # -7411
        """ "SWS HW: module 2, motor 1: init timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_PLAUSI_CHECK: Error._Sepia2Error.ValueType  # -7412
        """ "SWS HW: module 2, motor 1: plausi check" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_DAC_SET_CURRENT: Error._Sepia2Error.ValueType  # -7413
        """ "SWS HW: module 2, motor 1: DAC set current" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_TIMEOUT: Error._Sepia2Error.ValueType  # -7414
        """ "SWS HW: module 2, motor 1: timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_FLASH_WRITE_ERROR: Error._Sepia2Error.ValueType  # -7415
        """ "SWS HW: module 2, motor 1: flash write error" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -7416
        """ "SWS HW: module 2, motor 1: out of bounds" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_DATA_NOT_FOUND: Error._Sepia2Error.ValueType  # -7420
        """ "SWS HW: module 2, motor 2: data not found" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_INIT_TIMEOUT: Error._Sepia2Error.ValueType  # -7421
        """ "SWS HW: module 2, motor 2: init timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_PLAUSI_CHECK: Error._Sepia2Error.ValueType  # -7422
        """ "SWS HW: module 2, motor 2: plausi check" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_DAC_SET_CURRENT: Error._Sepia2Error.ValueType  # -7423
        """ "SWS HW: module 2, motor 2: DAC set current" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_TIMEOUT: Error._Sepia2Error.ValueType  # -7424
        """ "SWS HW: module 2, motor 2: timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_FLASH_WRITE_ERROR: Error._Sepia2Error.ValueType  # -7425
        """ "SWS HW: module 2, motor 2: flash write error" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -7426
        """ "SWS HW: module 2, motor 2: out of bounds" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_DATA_NOT_FOUND: Error._Sepia2Error.ValueType  # -7430
        """ "SWS HW: module 2, motor 3: data not found" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_INIT_TIMEOUT: Error._Sepia2Error.ValueType  # -7431
        """ "SWS HW: module 2, motor 3: init timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_PLAUSI_CHECK: Error._Sepia2Error.ValueType  # -7432
        """ "SWS HW: module 2, motor 3: plausi check" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_DAC_SET_CURRENT: Error._Sepia2Error.ValueType  # -7433
        """ "SWS HW: module 2, motor 3: DAC set current" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_TIMEOUT: Error._Sepia2Error.ValueType  # -7434
        """ "SWS HW: module 2, motor 3: timeout" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_FLASH_WRITE_ERROR: Error._Sepia2Error.ValueType  # -7435
        """ "SWS HW: module 2, motor 3: flash write error" """
        SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_OUT_OF_BOUNDS: Error._Sepia2Error.ValueType  # -7436
        """ "SWS HW: module 2, motor 3: out of bounds" """
        SEPIA2_ERR_LIB_TOO_MANY_USB_HANDLES: Error._Sepia2Error.ValueType  # -9001
        """ "LIB: too many USB handles" """
        SEPIA2_ERR_LIB_ILLEGAL_DEVICE_INDEX: Error._Sepia2Error.ValueType  # -9002
        """ "LIB: illegal device index" """
        SEPIA2_ERR_LIB_USB_DEVICE_OPEN_ERROR: Error._Sepia2Error.ValueType  # -9003
        """ "LIB: USB device open error" """
        SEPIA2_ERR_LIB_USB_DEVICE_BUSY_OR_BLOCKED: Error._Sepia2Error.ValueType  # -9004
        """ "LIB: USB device busy or blocked" """
        SEPIA2_ERR_LIB_USB_DEVICE_ALREADY_OPENED: Error._Sepia2Error.ValueType  # -9005
        """ "LIB: USB device already opened" """
        SEPIA2_ERR_LIB_UNKNOWN_USB_HANDLE: Error._Sepia2Error.ValueType  # -9006
        """ "LIB: unknown USB handle" """
        SEPIA2_ERR_LIB_SCM_828_MODULE_NOT_FOUND: Error._Sepia2Error.ValueType  # -9007
        """ "LIB: SCM 828 module not found" """
        SEPIA2_ERR_LIB_ILLEGAL_SLOT_NUMBER: Error._Sepia2Error.ValueType  # -9008
        """ "LIB: illegal slot number" """
        SEPIA2_ERR_LIB_REFERENCED_SLOT_IS_NOT_IN_USE: Error._Sepia2Error.ValueType  # -9009
        """ "LIB: referenced slot is not in use" """
        SEPIA2_ERR_LIB_THIS_IS_NO_SCM_828_MODULE: Error._Sepia2Error.ValueType  # -9010
        """ "LIB: this is no SCM 828 module" """
        SEPIA2_ERR_LIB_THIS_IS_NO_SOM_828_MODULE: Error._Sepia2Error.ValueType  # -9011
        """ "LIB: this is no SOM 828 module" """
        SEPIA2_ERR_LIB_THIS_IS_NO_SLM_828_MODULE: Error._Sepia2Error.ValueType  # -9012
        """ "LIB: this is no SLM 828 module" """
        SEPIA2_ERR_LIB_THIS_IS_NO_SML_828_MODULE: Error._Sepia2Error.ValueType  # -9013
        """ "LIB: this is no SML 828 module" """
        SEPIA2_ERR_LIB_THIS_IS_NO_SWM_828_MODULE: Error._Sepia2Error.ValueType  # -9014
        """ "LIB: this is no SWM 828 module" """
        SEPIA2_ERR_LIB_THIS_IS_NO_SSM_MODULE: Error._Sepia2Error.ValueType  # -9015
        """ "LIB: this is no SSM module" """
        SEPIA2_ERR_LIB_THIS_IS_NO_SWS_MODULE: Error._Sepia2Error.ValueType  # -9016
        """ "LIB: this is no SWS module" """
        SEPIA2_ERR_LIB_THIS_IS_NO_SPM_MODULE: Error._Sepia2Error.ValueType  # -9017
        """ "LIB: this is no SPM module" """
        SEPIA2_ERR_LIB_THIS_IS_NO_LMP1: Error._Sepia2Error.ValueType  # -9018
        """ "LIB: this is no LMP1 (metermodule w. shuttercontrol)" """
        SEPIA2_ERR_LIB_THIS_IS_NO_SOM_828_D_MODULE: Error._Sepia2Error.ValueType  # -9019
        """ "LIB: this is no SOM 828 D module" """
        SEPIA2_ERR_LIB_NO_MAP_FOUND: Error._Sepia2Error.ValueType  # -9020
        """ "LIB: no map found" """
        SEPIA2_ERR_LIB_THIS_IS_NO_LMP8: Error._Sepia2Error.ValueType  # -9021
        """ "LIB: this is no LMP8 (eightfold metermodule)" """
        SEPIA2_ERR_LIB_THIS_IS_NO_VCL_828_MODULE: Error._Sepia2Error.ValueType  # -9022
        """ "LIB: this is no VCL 828 module" """
        SEPIA2_ERR_LIB_THIS_IS_NO_VUV_NOR_VIR_MODULE: Error._Sepia2Error.ValueType  # -9023
        """ "LIB: this is no VUV nor VIR module" """
        SEPIA2_ERR_LIB_THIS_IS_NO_PRI_MODULE: Error._Sepia2Error.ValueType  # -9024
        """ "LIB: this is no PRI module" """
        SEPIA2_ERR_LIB_DEVICE_CHANGED_RE_INITIALISE_USB_DEVICE_LIST: Error._Sepia2Error.ValueType  # -9025
        """ "LIB: device changed, re-initialise USB device list" """
        SEPIA2_ERR_LIB_INAPPROPRIATE_USB_DEVICE: Error._Sepia2Error.ValueType  # -9026
        """ "LIB: inappropriate USB device" """
        SEPIA2_ERR_LIB_WRONG_USB_DRIVER_VERSION: Error._Sepia2Error.ValueType  # -9090
        """ "LIB: wrong USB driver version" """
        SEPIA2_ERR_LIB_UNKNOWN_FUNCTION: Error._Sepia2Error.ValueType  # -9900
        """ "LIB: unknown function" """
        SEPIA2_ERR_LIB_ILLEGAL_PARAMETER_ON_FUNCTION_CALL: Error._Sepia2Error.ValueType  # -9910
        """ "LIB: illegal parameter on function call" """
        SEPIA2_ERR_LIB_UNKNOWN_ERROR_CODE: Error._Sepia2Error.ValueType  # -9999
        """ "LIB: unknown error code" """

    class Sepia2Error(_Sepia2Error, metaclass=_Sepia2ErrorEnumTypeWrapper): ...
    SEPIA2_ERR_NO_ERROR: Error.Sepia2Error.ValueType  # 0
    """ "no error" - NOTE: This shouldn't be reachable code"""
    SEPIA2_ERR_FW_MEMORY_ALLOCATION_ERROR: Error.Sepia2Error.ValueType  # -1001
    """ "FW: memory allocation error" """
    SEPIA2_ERR_FW_CRC_ERROR_WHILE_CHECKING_SCM_828_MODULE: Error.Sepia2Error.ValueType  # -1002
    """ "FW: CRC error while checking SCM 828 module" """
    SEPIA2_ERR_FW_CRC_ERROR_WHILE_CHECKING_BACKPLANE: Error.Sepia2Error.ValueType  # -1003
    """ "FW: CRC error while checking backplane" """
    SEPIA2_ERR_FW_CRC_ERROR_WHILE_CHECKING_MODULE: Error.Sepia2Error.ValueType  # -1004
    """ "FW: CRC error while checking module" """
    SEPIA2_ERR_FW_MAPSIZE_ERROR: Error.Sepia2Error.ValueType  # -1005
    """ "FW: mapsize error" """
    SEPIA2_ERR_FW_UNKNOWN_ERROR_PHASE: Error.Sepia2Error.ValueType  # -1006
    """ "FW: unknown error phase" """
    SEPIA2_ERR_FW_INSUFFICIENT_FW_VERSION: Error.Sepia2Error.ValueType  # -1007
    """ "FW: insufficient FW version" """
    SEPIA2_ERR_FW_WRONG_WORKINGMODE: Error.Sepia2Error.ValueType  # -1008
    """ "FW: wrong workingmode" """
    SEPIA2_ERR_FW_ILLEGAL_MODULE_CHANGE: Error.Sepia2Error.ValueType  # -1111
    """ "FW: illegal module change" """
    SEPIA2_ERR_USB_WRONG_DRIVER_VERSION: Error.Sepia2Error.ValueType  # -2001
    """ "USB: wrong driver version" """
    SEPIA2_ERR_USB_OPEN_DEVICE_ERROR: Error.Sepia2Error.ValueType  # -2002
    """ "USB: open device error" """
    SEPIA2_ERR_USB_DEVICE_BUSY: Error.Sepia2Error.ValueType  # -2003
    """ "USB: device busy" """
    SEPIA2_ERR_USB_CLOSE_DEVICE_ERROR: Error.Sepia2Error.ValueType  # -2005
    """ "USB: close device error" """
    SEPIA2_ERR_USB_DEVICE_CHANGED: Error.Sepia2Error.ValueType  # -2006
    """ "USB: device changed" """
    SEPIA2_ERR_I2C_ADDRESS_ERROR: Error.Sepia2Error.ValueType  # -2010
    """ "I2C: address error" """
    SEPIA2_ERR_USB_DEVICE_INDEX_ERROR: Error.Sepia2Error.ValueType  # -2011
    """ "USB: device index error" """
    SEPIA2_ERR_I2C_ILLEGAL_MULTIPLEXER_PATH: Error.Sepia2Error.ValueType  # -2012
    """ "I2C: illegal multiplexer path" """
    SEPIA2_ERR_I2C_ILLEGAL_MULTIPLEXER_LEVEL: Error.Sepia2Error.ValueType  # -2013
    """ "I2C: illegal multiplexer level" """
    SEPIA2_ERR_I2C_ILLEGAL_SLOT_ID: Error.Sepia2Error.ValueType  # -2014
    """ "I2C: illegal slot id" """
    SEPIA2_ERR_FRAM_NO_UPTIME_COUNTER: Error.Sepia2Error.ValueType  # -2015
    """ "FRAM: no uptime counter" """
    SEPIA2_ERR_FRAM_BLOCKWRITE_ERROR: Error.Sepia2Error.ValueType  # -2020
    """ "FRAM: blockwrite error" """
    SEPIA2_ERR_FRAM_BLOCKREAD_ERROR: Error.Sepia2Error.ValueType  # -2021
    """ "FRAM: blockread error" """
    SEPIA2_ERR_FRAM_CRC_BLOCKCHECK_ERROR: Error.Sepia2Error.ValueType  # -2022
    """ "FRAM: CRC blockcheck error" """
    SEPIA2_ERR_RAM_BLOCK_ALLOCATION_ERROR: Error.Sepia2Error.ValueType  # -2023
    """ "RAM: block allocation error" """
    SEPIA2_ERR_RAM_SECURE_MEMORY_HANDLING_ERROR: Error.Sepia2Error.ValueType  # -2024
    """ "RAM: secure memory handling error" """
    SEPIA2_ERR_I2C_INITIALISING_COMMAND_EXECUTION_ERROR: Error.Sepia2Error.ValueType  # -2100
    """ "I2C: initialising command execution error" """
    SEPIA2_ERR_I2C_FETCHING_INITIALISING_COMMANDS_ERROR: Error.Sepia2Error.ValueType  # -2101
    """ "I2C: fetching initialising commands error" """
    SEPIA2_ERR_I2C_WRITING_INITIALISING_COMMANDS_ERROR: Error.Sepia2Error.ValueType  # -2102
    """ "I2C: writing initialising commands error" """
    SEPIA2_ERR_I2C_MODULE_CALIBRATING_ERROR: Error.Sepia2Error.ValueType  # -2200
    """ "I2C: module calibrating error" """
    SEPIA2_ERR_I2C_FETCHING_CALIBRATING_COMMANDS_ERROR: Error.Sepia2Error.ValueType  # -2201
    """ "I2C: fetching calibrating commands error" """
    SEPIA2_ERR_I2C_WRITING_CALIBRATING_COMMANDS_ERROR: Error.Sepia2Error.ValueType  # -2202
    """ "I2C: writing calibrating commands error" """
    SEPIA2_ERR_DCL_FILE_OPEN_ERROR: Error.Sepia2Error.ValueType  # -2301
    """ "DCL: file open error" """
    SEPIA2_ERR_DCL_WRONG_FILE_LENGTH: Error.Sepia2Error.ValueType  # -2302
    """ "DCL: wrong file length" """
    SEPIA2_ERR_DCL_FILE_READ_ERROR: Error.Sepia2Error.ValueType  # -2303
    """ "DCL: file read error" """
    SEPIA2_ERR_FRAM_IS_WRITE_PROTECTED: Error.Sepia2Error.ValueType  # -2304
    """ "FRAM: is write protected" """
    SEPIA2_ERR_DCL_FILE_SPECIFIES_DIFFERENT_MODULETYPE: Error.Sepia2Error.ValueType  # -2305
    """ "DCL: file specifies different moduletype" """
    SEPIA2_ERR_DCL_FILE_SPECIFIES_DIFFERENT_SERIAL_NUMBER: Error.Sepia2Error.ValueType  # -2306
    """ "DCL: file specifies different serial number" """
    SEPIA2_ERR_I2C_INVALID_ARGUMENT: Error.Sepia2Error.ValueType  # -3001
    """ "I2C: invalid argument" """
    SEPIA2_ERR_I2C_NO_ACKNOWLEDGE_ON_WRITE_ADRESSBYTE: Error.Sepia2Error.ValueType  # -3002
    """ "I2C: no acknowledge on write adressbyte" """
    SEPIA2_ERR_I2C_NO_ACKNOWLEDGE_ON_READ_ADRESSBYTE: Error.Sepia2Error.ValueType  # -3003
    """ "I2C: no acknowledge on read adressbyte" """
    SEPIA2_ERR_I2C_NO_ACKNOWLEDGE_ON_WRITE_DATABYTE: Error.Sepia2Error.ValueType  # -3004
    """ "I2C: no acknowledge on write databyte" """
    SEPIA2_ERR_I2C_READ_BACK_ERROR: Error.Sepia2Error.ValueType  # -3005
    """ "I2C: read back error" """
    SEPIA2_ERR_I2C_READ_ERROR: Error.Sepia2Error.ValueType  # -3006
    """ "I2C: read error" """
    SEPIA2_ERR_I2C_WRITE_ERROR: Error.Sepia2Error.ValueType  # -3007
    """ "I2C: write error" """
    SEPIA2_ERR_I_O_FILE_ERROR: Error.Sepia2Error.ValueType  # -3009
    """ "I/O: file error" """
    SEPIA2_ERR_I2C_MULTIPLEXER_ERROR: Error.Sepia2Error.ValueType  # -3014
    """ "I2C: multiplexer error" """
    SEPIA2_ERR_I2C_MULTIPLEXER_PATH_ERROR: Error.Sepia2Error.ValueType  # -3015
    """ "I2C: multiplexer path error" """
    SEPIA2_ERR_USB_INIT_FAILED: Error.Sepia2Error.ValueType  # -3200
    """ "USB: init failed" """
    SEPIA2_ERR_USB_INVALID_ARGUMENT: Error.Sepia2Error.ValueType  # -3201
    """ "USB: invalid argument" """
    SEPIA2_ERR_USB_DEVICE_STILL_OPEN: Error.Sepia2Error.ValueType  # -3202
    """ "USB: device still open" """
    SEPIA2_ERR_USB_NO_MEMORY: Error.Sepia2Error.ValueType  # -3203
    """ "USB: no memory" """
    SEPIA2_ERR_USB_OPEN_FAILED: Error.Sepia2Error.ValueType  # -3204
    """ "USB: open failed" """
    SEPIA2_ERR_USB_GET_DESCRIPTOR_FAILED: Error.Sepia2Error.ValueType  # -3205
    """ "USB: get descriptor failed" """
    SEPIA2_ERR_USB_INAPPROPRIATE_DEVICE: Error.Sepia2Error.ValueType  # -3206
    """ "USB: inappropriate device" """
    SEPIA2_ERR_USB_BUSY_DEVICE: Error.Sepia2Error.ValueType  # -3207
    """ "USB: busy device" """
    SEPIA2_ERR_USB_INVALID_HANDLE: Error.Sepia2Error.ValueType  # -3208
    """ "USB: invalid handle" """
    SEPIA2_ERR_USB_INVALID_DESCRIPTOR_BUFFER: Error.Sepia2Error.ValueType  # -3209
    """ "USB: invalid descriptor buffer" """
    SEPIA2_ERR_USB_IOCTRL_FAILED: Error.Sepia2Error.ValueType  # -3210
    """ "USB: IOCTRL failed" """
    SEPIA2_ERR_USB_VCMD_FAILED: Error.Sepia2Error.ValueType  # -3211
    """ "USB: vcmd failed" """
    SEPIA2_ERR_USB_NO_SUCH_PIPE: Error.Sepia2Error.ValueType  # -3212
    """ "USB: no such pipe" """
    SEPIA2_ERR_USB_REGISTER_NOTIFICATION_FAILED: Error.Sepia2Error.ValueType  # -3213
    """ "USB: register notification failed" """
    SEPIA2_ERR_USB_UNKNOWN_DEVICE: Error.Sepia2Error.ValueType  # -3214
    """ "USB: unknown device" """
    SEPIA2_ERR_USB_WRONG_DRIVER: Error.Sepia2Error.ValueType  # -3215
    """ "USB: wrong driver" """
    SEPIA2_ERR_USB_WINDOWS_ERROR: Error.Sepia2Error.ValueType  # -3216
    """ "USB: windows error" """
    SEPIA2_ERR_USB_DEVICE_NOT_OPEN: Error.Sepia2Error.ValueType  # -3217
    """ "USB: device not open" """
    SEPIA2_ERR_I2C_DEVICE_ERROR: Error.Sepia2Error.ValueType  # -3256
    """ "I2C: device error" """
    SEPIA2_ERR_LMP1_ADC_TABLES_NOT_FOUND: Error.Sepia2Error.ValueType  # -3501
    """ "LMP1: ADC tables not found" """
    SEPIA2_ERR_LMP1_ADC_OVERFLOW: Error.Sepia2Error.ValueType  # -3502
    """ "LMP1: ADC overflow" """
    SEPIA2_ERR_LMP1_ADC_UNDERFLOW: Error.Sepia2Error.ValueType  # -3503
    """ "LMP1: ADC underflow" """
    SEPIA2_ERR_SCM_VOLTAGE_LIMITS_TABLE_NOT_FOUND: Error.Sepia2Error.ValueType  # -4001
    """ "SCM: voltage limits table not found" """
    SEPIA2_ERR_SCM_VOLTAGE_SCALING_LIST_NOT_FOUND: Error.Sepia2Error.ValueType  # -4002
    """ "SCM: voltage scaling list not found" """
    SEPIA2_ERR_SCM_REPEATEDLY_MEASURED_VOLTAGE_FAILURE: Error.Sepia2Error.ValueType  # -4003
    """ "SCM: repeatedly measured voltage failure" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_0_VOLTAGE_TOO_LOW: Error.Sepia2Error.ValueType  # -4010
    """ "SCM: power supply line 0: voltage too low" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_1_VOLTAGE_TOO_LOW: Error.Sepia2Error.ValueType  # -4011
    """ "SCM: power supply line 1: voltage too low" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_2_VOLTAGE_TOO_LOW: Error.Sepia2Error.ValueType  # -4012
    """ "SCM: power supply line 2: voltage too low" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_3_VOLTAGE_TOO_LOW: Error.Sepia2Error.ValueType  # -4013
    """ "SCM: power supply line 3: voltage too low" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_4_VOLTAGE_TOO_LOW: Error.Sepia2Error.ValueType  # -4014
    """ "SCM: power supply line 4: voltage too low" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_5_VOLTAGE_TOO_LOW: Error.Sepia2Error.ValueType  # -4015
    """ "SCM: power supply line 5: voltage too low" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_6_VOLTAGE_TOO_LOW: Error.Sepia2Error.ValueType  # -4016
    """ "SCM: power supply line 6: voltage too low" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_7_VOLTAGE_TOO_LOW: Error.Sepia2Error.ValueType  # -4017
    """ "SCM: power supply line 7: voltage too low" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_0_VOLTAGE_TOO_HIGH: Error.Sepia2Error.ValueType  # -4020
    """ "SCM: power supply line 0: voltage too high" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_1_VOLTAGE_TOO_HIGH: Error.Sepia2Error.ValueType  # -4021
    """ "SCM: power supply line 1: voltage too high" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_2_VOLTAGE_TOO_HIGH: Error.Sepia2Error.ValueType  # -4022
    """ "SCM: power supply line 2: voltage too high" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_3_VOLTAGE_TOO_HIGH: Error.Sepia2Error.ValueType  # -4023
    """ "SCM: power supply line 3: voltage too high" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_4_VOLTAGE_TOO_HIGH: Error.Sepia2Error.ValueType  # -4024
    """ "SCM: power supply line 4: voltage too high" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_5_VOLTAGE_TOO_HIGH: Error.Sepia2Error.ValueType  # -4025
    """ "SCM: power supply line 5: voltage too high" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_6_VOLTAGE_TOO_HIGH: Error.Sepia2Error.ValueType  # -4026
    """ "SCM: power supply line 6: voltage too high" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_7_VOLTAGE_TOO_HIGH: Error.Sepia2Error.ValueType  # -4027
    """ "SCM: power supply line 7: voltage too high" """
    SEPIA2_ERR_SCM_POWER_SUPPLY_LASER_TURNING_OFF_VOLTAGE_TOO_HIGH: Error.Sepia2Error.ValueType  # -4030
    """ "SCM: power supply laser turning-off-voltage too high" """
    SEPIA2_ERR_SCM_INVALID_TEMPERATURE_TABLE_COUNT: Error.Sepia2Error.ValueType  # -4040
    """ "SCM: invalid temperature table count" """
    SEPIA2_ERR_SCM_TCONFG_TABLE_READ_FAILED: Error.Sepia2Error.ValueType  # -4041
    """ "SCM: tconfg table read failed" """
    SEPIA2_ERR_SCM_INVALID_NUMBER_OF_TABLE_ENTRIES: Error.Sepia2Error.ValueType  # -4042
    """ "SCM: invalid number of table entries" """
    SEPIA2_ERR_SCM_INVALID_TIMERTICK_VALUE: Error.Sepia2Error.ValueType  # -4043
    """ "SCM: invalid timertick value" """
    SEPIA2_ERR_SCM_INVALID_TEMPERATURE_VALUE_TABLE: Error.Sepia2Error.ValueType  # -4044
    """ "SCM: invalid temperature value table" """
    SEPIA2_ERR_SCM_INVALID_DAC_CONTROL_TABLE_A: Error.Sepia2Error.ValueType  # -4045
    """ "SCM: invalid DAC control table A" """
    SEPIA2_ERR_SCM_INVALID_DAC_CONTROL_TABLE_B: Error.Sepia2Error.ValueType  # -4046
    """ "SCM: invalid DAC control table B" """
    SEPIA2_ERR_SCM_TEMPERATURE_TABLE_READ_FAILED: Error.Sepia2Error.ValueType  # -4047
    """ "SCM: temperature table read failed" """
    SEPIA2_ERR_SOM_INT_OSCILLATOR_S_FREQ_LIST_NOT_FOUND: Error.Sepia2Error.ValueType  # -5001
    """ "SOM: int. oscillator's freq.-list not found" """
    SEPIA2_ERR_SOM_TRIGGER_MODE_LIST_NOT_FOUND: Error.Sepia2Error.ValueType  # -5002
    """ "SOM: trigger mode list not found" """
    SEPIA2_ERR_SOM_TRIGGER_LEVEL_NOT_FOUND: Error.Sepia2Error.ValueType  # -5003
    """ "SOM: trigger level not found" """
    SEPIA2_ERR_SOM_PREDIVIDER_PRETRIGGER_OR_TRIGGERMASK_NOT_FOUND: Error.Sepia2Error.ValueType  # -5004
    """ "SOM: predivider, pretrigger or triggermask not found" """
    SEPIA2_ERR_SOM_BURSTLENGTH_NOT_FOUND: Error.Sepia2Error.ValueType  # -5005
    """ "SOM: burstlength not found" """
    SEPIA2_ERR_SOM_OUTPUT_AND_SYNC_ENABLE_NOT_FOUND: Error.Sepia2Error.ValueType  # -5006
    """ "SOM: output and sync enable not found" """
    SEPIA2_ERR_SOM_TRIGGER_LEVEL_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -5007
    """ "SOM: trigger level out of bounds" """
    SEPIA2_ERR_SOM_ILLEGAL_FREQUENCY_TRIGGERMODE: Error.Sepia2Error.ValueType  # -5008
    """ "SOM: illegal frequency / triggermode" """
    SEPIA2_ERR_SOM_ILLEGAL_FREQUENCY_DIVIDER: Error.Sepia2Error.ValueType  # -5009
    """ "SOM: illegal frequency divider" """
    SEPIA2_ERR_SOM_ILLEGAL_PRESYNC: Error.Sepia2Error.ValueType  # -5010
    """ "SOM: illegal presync (greater than divider)" """
    SEPIA2_ERR_SOM_ILLEGAL_BURST_LENGTH: Error.Sepia2Error.ValueType  # -5011
    """ "SOM: illegal burst length (>/= 2^24 or < 0)" """
    SEPIA2_ERR_SOM_AUX_IO_CTRL_NOT_FOUND: Error.Sepia2Error.ValueType  # -5012
    """ "SOM: AUX I/O control data not found" """
    SEPIA2_ERR_SOM_ILLEGAL_AUX_OUT_CTRL: Error.Sepia2Error.ValueType  # -5013
    """ "SOM: illegal AUX output control data" """
    SEPIA2_ERR_SOM_ILLEGAL_AUX_IN_CTRL: Error.Sepia2Error.ValueType  # -5014
    """ "SOM: illegal AUX input control data" """
    SEPIA2_ERR_SOMD_INT_OSCILLATOR_S_FREQ_LIST_NOT_FOUND: Error.Sepia2Error.ValueType  # -5051
    """ "SOMD: int. oscillator's freq.-list not found" """
    SEPIA2_ERR_SOMD_TRIGGER_MODE_LIST_NOT_FOUND: Error.Sepia2Error.ValueType  # -5052
    """ "SOMD: trigger mode list not found" """
    SEPIA2_ERR_SOMD_TRIGGER_LEVEL_NOT_FOUND: Error.Sepia2Error.ValueType  # -5053
    """ "SOMD: trigger level not found" """
    SEPIA2_ERR_SOMD_PREDIVIDER_PRETRIGGER_OR_TRIGGERMASK_NOT_FOUND: Error.Sepia2Error.ValueType  # -5054
    """ "SOMD: predivider, pretrigger or triggermask not found" """
    SEPIA2_ERR_SOMD_BURSTLENGTH_NOT_FOUND: Error.Sepia2Error.ValueType  # -5055
    """ "SOMD: burstlength not found" """
    SEPIA2_ERR_SOMD_OUTPUT_AND_SYNC_ENABLE_NOT_FOUND: Error.Sepia2Error.ValueType  # -5056
    """ "SOMD: output and sync enable not found" """
    SEPIA2_ERR_SOMD_TRIGGER_LEVEL_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -5057
    """ "SOMD: trigger level out of bounds" """
    SEPIA2_ERR_SOMD_ILLEGAL_FREQUENCY_TRIGGERMODE: Error.Sepia2Error.ValueType  # -5058
    """ "SOMD: illegal frequency / triggermode" """
    SEPIA2_ERR_SOMD_ILLEGAL_FREQUENCY_DIVIDER: Error.Sepia2Error.ValueType  # -5059
    """ "SOMD: illegal frequency divider" """
    SEPIA2_ERR_SOMD_ILLEGAL_PRESYNC: Error.Sepia2Error.ValueType  # -5060
    """ "SOMD: illegal presync (greater than divider)" """
    SEPIA2_ERR_SOMD_ILLEGAL_BURST_LENGTH: Error.Sepia2Error.ValueType  # -5061
    """ "SOMD: illegal burst length (>/= 2^24 or < 0)" """
    SEPIA2_ERR_SOMD_AUX_IO_CTRL_NOT_FOUND: Error.Sepia2Error.ValueType  # -5062
    """ "SOMD: AUX I/O control data not found" """
    SEPIA2_ERR_SOMD_ILLEGAL_AUX_OUT_CTRL: Error.Sepia2Error.ValueType  # -5063
    """ "SOMD: illegal AUX output control data" """
    SEPIA2_ERR_SOMD_ILLEGAL_AUX_IN_CTRL: Error.Sepia2Error.ValueType  # -5064
    """ "SOMD: illegal AUX input control data" """
    SEPIA2_ERR_SOMD_ILLEGAL_OUT_MUX_CTRL: Error.Sepia2Error.ValueType  # -5071
    """ "SOMD: illegal output multiplexer control data" """
    SEPIA2_ERR_SOMD_OUTPUT_DELAY_DATA_NOT_FOUND: Error.Sepia2Error.ValueType  # -5072
    """ "SOMD: output delay data not found" """
    SEPIA2_ERR_SOMD_ILLEGAL_OUTPUT_DELAY_DATA: Error.Sepia2Error.ValueType  # -5073
    """ "SOMD: illegal output delay data" """
    SEPIA2_ERR_SOMD_DELAY_NOT_ALLOWED_IN_TRIGGER_MODE: Error.Sepia2Error.ValueType  # -5074
    """ "SOMD: delay not allowed in current trigger mode" """
    SEPIA2_ERR_SOMD_DEVICE_INITIALIZING: Error.Sepia2Error.ValueType  # -5075
    """ "SOMD: device initializing" """
    SEPIA2_ERR_SOMD_DEVICE_BUSY: Error.Sepia2Error.ValueType  # -5076
    """ "SOMD: device busy" """
    SEPIA2_ERR_SOMD_PLL_NOT_LOCKED: Error.Sepia2Error.ValueType  # -5077
    """ "SOMD: PLL not locked" """
    SEPIA2_ERR_SOMD_FW_UPDATE_FAILED: Error.Sepia2Error.ValueType  # -5080
    """ "SOMD: firmware update failed" """
    SEPIA2_ERR_SOMD_FW_CRC_CHECK_FAILED: Error.Sepia2Error.ValueType  # -5081
    """ "SOMD: firmware CRC check failed" """
    SEPIA2_ERR_SOMD_HW_TRIGGERSOURCE_ERROR: Error.Sepia2Error.ValueType  # -5101
    """ "SOMD HW: triggersource error" """
    SEPIA2_ERR_SOMD_HW_SYCHRONIZE_NOW_ERROR: Error.Sepia2Error.ValueType  # -5102
    """ "SOMD HW: sychronize now error" """
    SEPIA2_ERR_SOMD_HW_SYNC_RANGE_ERROR: Error.Sepia2Error.ValueType  # -5103
    """ "SOMD HW: SYNC range error" """
    SEPIA2_ERR_SOMD_HW_ILLEGAL_OUT_MUX_CTRL: Error.Sepia2Error.ValueType  # -5104
    """ "SOMD HW: illegal output multiplexer control data" """
    SEPIA2_ERR_SOMD_HW_SET_DELAY_ERROR: Error.Sepia2Error.ValueType  # -5105
    """ "SOMD HW: set delay error" """
    SEPIA2_ERR_SOMD_HW_AUX_IO_COMMAND_ERROR: Error.Sepia2Error.ValueType  # -5106
    """ "SOMD HW: AUX I/O command error" """
    SEPIA2_ERR_SOMD_HW_PLL_NOT_STABLE: Error.Sepia2Error.ValueType  # -5107
    """ "SOMD HW: PLL not stable" """
    SEPIA2_ERR_SOMD_HW_BURST_LENGTH_ERROR: Error.Sepia2Error.ValueType  # -5108
    """ "SOMD HW: burst length error" """
    SEPIA2_ERR_SOMD_HW_OUT_MUX_COMMAND_ERROR: Error.Sepia2Error.ValueType  # -5109
    """ "SOMD HW: output multiplexer command error" """
    SEPIA2_ERR_SOMD_HW_COARSE_DELAY_SET_ERROR: Error.Sepia2Error.ValueType  # -5110
    """ "SOMD HW: coarse delay set error" """
    SEPIA2_ERR_SOMD_HW_FINE_DELAY_SET_ERROR: Error.Sepia2Error.ValueType  # -5111
    """ "SOMD HW: fine delay set error" """
    SEPIA2_ERR_SOMD_HW_FW_EPROM_ERROR: Error.Sepia2Error.ValueType  # -5112
    """ "SOMD HW: firmware EPROM error" """
    SEPIA2_ERR_SOMD_HW_CRC_ERROR_ON_WRITING_FIRMWARE: Error.Sepia2Error.ValueType  # -5113
    """ "SOMD HW: CRC error on writing firmware" """
    SEPIA2_ERR_SOMD_HW_CALIBRATION_DATA_NOT_FOUND: Error.Sepia2Error.ValueType  # -5114
    """ "SOMD HW: calibration data not found" """
    SEPIA2_ERR_SOMD_HW_WRONG_EXTERNAL_FREQUENCY: Error.Sepia2Error.ValueType  # -5115
    """ "SOMD HW: wrong external frequency" """
    SEPIA2_ERR_SOMD_HW_EXTERNAL_FREQUENCY_NOT_STABLE: Error.Sepia2Error.ValueType  # -5116
    """ "SOMD HW: external frequency not stable" """
    SEPIA2_ERR_SLM_ILLEGAL_FREQUENCY_TRIGGERMODE: Error.Sepia2Error.ValueType  # -6001
    """ "SLM: illegal frequency / triggermode" """
    SEPIA2_ERR_SLM_ILLEGAL_INTENSITY: Error.Sepia2Error.ValueType  # -6002
    """ "SLM: illegal intensity (> 100% or < 0%)" """
    SEPIA2_ERR_SLM_ILLEGAL_HEAD_TYPE: Error.Sepia2Error.ValueType  # -6003
    """ "SLM: illegal head type" """
    SEPIA2_ERR_SML_ILLEGAL_INTENSITY: Error.Sepia2Error.ValueType  # -6501
    """ "SML: illegal intensity (> 100% or < 0%)" """
    SEPIA2_ERR_SML_POWER_SCALE_TABLES_NOT_FOUND: Error.Sepia2Error.ValueType  # -6502
    """ "SML: power scale tables not found" """
    SEPIA2_ERR_SML_ILLEGAL_HEAD_TYPE: Error.Sepia2Error.ValueType  # -6503
    """ "SML: illegal head type" """
    SEPIA2_ERR_VUV_VIR_SCALING_TABLES_NOT_FOUND: Error.Sepia2Error.ValueType  # -6511
    """ "VUV/VIR: scaling tables not found" """
    SEPIA2_ERR_VUV_VIR_DEVICE_TYPE_NOT_FOUND: Error.Sepia2Error.ValueType  # -6512
    """ "VUV/VIR: device type not found" """
    SEPIA2_ERR_VUV_VIR_ILLEGAL_TRIGGER_SOURCE_INDEX: Error.Sepia2Error.ValueType  # -6513
    """ "VUV/VIR: illegal trigger source index" """
    SEPIA2_ERR_VUV_VIR_ILLEGAL_FREQUENCY_DIVIDER_INDEX: Error.Sepia2Error.ValueType  # -6514
    """ "VUV/VIR: illegal frequency divider index" """
    SEPIA2_ERR_VUV_VIR_ILLEGAL_TRIGGER_LEVEL_VALUE: Error.Sepia2Error.ValueType  # -6515
    """ "VUV/VIR: illegal trigger level value" """
    SEPIA2_ERR_VUV_VIR_TRIGGER_DATA_NOT_FOUND: Error.Sepia2Error.ValueType  # -6516
    """ "VUV/VIR: trigger data not found" """
    SEPIA2_ERR_VUV_VIR_ILLEGAL_PUMP_REGISTER_READ_INDEX: Error.Sepia2Error.ValueType  # -6517
    """ "VUV/VIR: illegal pump register read index" """
    SEPIA2_ERR_VUV_VIR_ILLEGAL_PUMP_REGISTER_WRITE_INDEX: Error.Sepia2Error.ValueType  # -6518
    """ "VUV/VIR: illegal pump register write index" """
    SEPIA2_ERR_VUV_VIR_INTENSITY_DATA_NOT_FOUND: Error.Sepia2Error.ValueType  # -6519
    """ "VUV/VIR: intensity data not found" """
    SEPIA2_ERR_VUV_VIR_ILLEGAL_INTENSITY_DATA: Error.Sepia2Error.ValueType  # -6520
    """ "VUV/VIR: illegal intensity data" """
    SEPIA2_ERR_VUV_VIR_UNSUPPORTED_OPTION: Error.Sepia2Error.ValueType  # -6521
    """ "VUV/VIR: unsupported option" """
    SEPIA2_ERR_PRI_UI_CONSTANTS_TABLES_NOT_FOUND: Error.Sepia2Error.ValueType  # -6531
    """ "PRI: UI-constants tables not found" """
    SEPIA2_ERR_PRI_WAVELENGTHS_TABLE_NOT_FOUND: Error.Sepia2Error.ValueType  # -6532
    """ "PRI: wavelengths table not found" """
    SEPIA2_ERR_PRI_ILLEGAL_WAVELENGTH_INDEX: Error.Sepia2Error.ValueType  # -6533
    """ "PRI: illegal wavelength index" """
    SEPIA2_ERR_PRI_ERROR_ON_WRITING_WAVELENGTH_INDEX: Error.Sepia2Error.ValueType  # -6534
    """ "PRI: error on writing wavelength index" """
    SEPIA2_ERR_PRI_OPERATION_MODE_TEXTS_NOT_FOUND: Error.Sepia2Error.ValueType  # -6535
    """ "PRI: operation mode texts not found" """
    SEPIA2_ERR_PRI_OPERATION_MODE_COMMANDS_NOT_FOUND: Error.Sepia2Error.ValueType  # -6536
    """ "PRI: operation mode commands not found" """
    SEPIA2_ERR_PRI_ILLEGAL_OPERATION_MODE_INDEX: Error.Sepia2Error.ValueType  # -6537
    """ "PRI: illegal operation mode index" """
    SEPIA2_ERR_PRI_ERROR_ON_WRITING_OPERATION_MODE_INDEX: Error.Sepia2Error.ValueType  # -6538
    """ "PRI: error on writing operation mode index" """
    SEPIA2_ERR_PRI_TRIGGER_SOURCE_TEXTS_NOT_FOUND: Error.Sepia2Error.ValueType  # -6539
    """ "PRI: trigger source texts not found" """
    SEPIA2_ERR_PRI_TRIGGER_SOURCE_COMMANDS_NOT_FOUND: Error.Sepia2Error.ValueType  # -6540
    """ "PRI: trigger source commands not found" """
    SEPIA2_ERR_PRI_ILLEGAL_TRIGGER_SOURCE_INDEX: Error.Sepia2Error.ValueType  # -6541
    """ "PRI: illegal trigger source index" """
    SEPIA2_ERR_PRI_ERROR_ON_WRITING_TRIGGER_SOURCE_INDEX: Error.Sepia2Error.ValueType  # -6542
    """ "PRI: error on writing trigger source index" """
    SEPIA2_ERR_PRI_ILLEGAL_TRIGGER_LEVEL: Error.Sepia2Error.ValueType  # -6543
    """ "PRI: illegal trigger level" """
    SEPIA2_ERR_PRI_ERROR_ON_WRITING_TRIGGER_LEVEL: Error.Sepia2Error.ValueType  # -6544
    """ "PRI: error on writing trigger level" """
    SEPIA2_ERR_PRI_ILLEGAL_INTENSITY_DATA: Error.Sepia2Error.ValueType  # -6545
    """ "PRI: illegal intensity data" """
    SEPIA2_ERR_PRI_ERROR_ON_WRITING_INTENSITY_DATA: Error.Sepia2Error.ValueType  # -6546
    """ "PRI: error on writing intensity data" """
    SEPIA2_ERR_PRI_ILLEGAL_FREQUENCY_DATA: Error.Sepia2Error.ValueType  # -6547
    """ "PRI: illegal frequency data" """
    SEPIA2_ERR_PRI_ERROR_ON_WRITING_FREQUENCY_DATA: Error.Sepia2Error.ValueType  # -6548
    """ "PRI: error on writing frequency data" """
    SEPIA2_ERR_PRI_ILLEGAL_GATING_DATA: Error.Sepia2Error.ValueType  # -6549
    """ "PRI: illegal gating data" """
    SEPIA2_ERR_PRI_ERROR_ON_WRITING_GATING_DATA: Error.Sepia2Error.ValueType  # -6550
    """ "PRI: error on writing gating data" """
    SEPIA2_ERR_SWM_CALTABLES_NOT_FOUND: Error.Sepia2Error.ValueType  # -6701
    """ "SWM: calibration tables not found" """
    SEPIA2_ERR_SWM_ILLEGAL_CURVE_INDEX: Error.Sepia2Error.ValueType  # -6702
    """ "SWM: illegal curve index" """
    SEPIA2_ERR_SWM_ILLEGAL_TIMEBASE_RANGE_INDEX: Error.Sepia2Error.ValueType  # -6703
    """ "SWM: illegal timebase range index" """
    SEPIA2_ERR_SWM_ILLEGAL_PULSE_AMPLITUDE: Error.Sepia2Error.ValueType  # -6704
    """ "SWM: illegal pulse amplitude" """
    SEPIA2_ERR_SWM_ILLEGAL_RAMP_SLEW_RATE: Error.Sepia2Error.ValueType  # -6705
    """ "SWM: illegal ramp slew rate" """
    SEPIA2_ERR_SWM_ILLEGAL_PULSE_START_DELAY: Error.Sepia2Error.ValueType  # -6706
    """ "SWM: illegal pulse start delay" """
    SEPIA2_ERR_SWM_ILLEGAL_RAMP_START_DELAY: Error.Sepia2Error.ValueType  # -6707
    """ "SWM: illegal ramp start delay" """
    SEPIA2_ERR_SWM_ILLEGAL_WAVE_STOP_DELAY: Error.Sepia2Error.ValueType  # -6708
    """ "SWM: illegal wave stop delay" """
    SEPIA2_ERR_SWM_ILLEGAL_TABLENAME: Error.Sepia2Error.ValueType  # -6709
    """ "SWM: illegal tablename" """
    SEPIA2_ERR_SWM_ILLEGAL_TABLE_INDEX: Error.Sepia2Error.ValueType  # -6710
    """ "SWM: illegal table index" """
    SEPIA2_ERR_SWM_ILLEGAL_TABLE_FIELD: Error.Sepia2Error.ValueType  # -6711
    """ "SWM: illegal table field" """
    SEPIA2_ERR_SWM_EXT_ATTENUATION_NOT_FOUND: Error.Sepia2Error.ValueType  # -6712
    """ "SWM: ext. attenuation not found" """
    SEPIA2_ERR_SWM_ILLEGAL_ATTENUATION_VALUE: Error.Sepia2Error.ValueType  # -6713
    """ "SWM: illegal attenuation value" """
    SEPIA2_ERR_VCL_UI_CONSTANTS_NOT_FOUND: Error.Sepia2Error.ValueType  # -6751
    """ "VCL: UI-constants not found" """
    SEPIA2_ERR_VCL_TEMPERATURE_CALTABLE_NOT_FOUND: Error.Sepia2Error.ValueType  # -6752
    """ "VCL: temperature calibration table not found" """
    SEPIA2_ERR_VCL_BIAS_VOLTAGE_CALTABLE_NOT_FOUND: Error.Sepia2Error.ValueType  # -6753
    """ "VCL: bias voltage calibration table not found" """
    SEPIA2_ERR_VCL_ILLEGAL_TEMPERATURE: Error.Sepia2Error.ValueType  # -6754
    """ "VCL: illegal temperature" """
    SEPIA2_ERR_VCL_ILLEGAL_BIAS_VOLTAGE: Error.Sepia2Error.ValueType  # -6755
    """ "VCL: illegal bias voltage" """
    SEPIA2_ERR_SPM_ILLEGAL_INPUT_VALUE: Error.Sepia2Error.ValueType  # -7001
    """ "SPM: illegal input value" """
    SEPIA2_ERR_SPM_VALUE_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -7006
    """ "SPM: value out of bounds" """
    SEPIA2_ERR_SPM_FW_OUT_OF_MEMORY: Error.Sepia2Error.ValueType  # -7011
    """ "SPM FW: out of memory" """
    SEPIA2_ERR_SPM_FW_UPDATE_FAILED: Error.Sepia2Error.ValueType  # -7013
    """ "SPM FW: update failed" """
    SEPIA2_ERR_SPM_FW_CRC_CHECK_FAILED: Error.Sepia2Error.ValueType  # -7014
    """ "SPM FW: CRC check failed" """
    SEPIA2_ERR_SPM_FW_FLASH_DELETION_FAILED: Error.Sepia2Error.ValueType  # -7015
    """ "SPM FW: flash deletion failed" """
    SEPIA2_ERR_SPM_FW_FUNCTION_NOT_IMPLEMENTED: Error.Sepia2Error.ValueType  # -7017
    """ "SPM FW: function not implemented" """
    SEPIA2_ERR_SPM_FW_FILE_OPEN_ERROR: Error.Sepia2Error.ValueType  # -7021
    """ "SPM FW: file open error" """
    SEPIA2_ERR_SPM_FW_FILE_READ_ERROR: Error.Sepia2Error.ValueType  # -7022
    """ "SPM FW: file read error" """
    SEPIA2_ERR_SSM_SCALING_TABLES_NOT_FOUND: Error.Sepia2Error.ValueType  # -7051
    """ "SSM: scaling tables not found" """
    SEPIA2_ERR_SSM_ILLEGAL_TRIGGER_MODE: Error.Sepia2Error.ValueType  # -7052
    """ "SSM: illegal trigger mode" """
    SEPIA2_ERR_SSM_ILLEGAL_TRIGGER_LEVEL_VALUE: Error.Sepia2Error.ValueType  # -7053
    """ "SSM: illegal trigger level value" """
    SEPIA2_ERR_SSM_ILLEGAL_CORRECTION_VALUE: Error.Sepia2Error.ValueType  # -7054
    """ "SSM: illegal correction value" """
    SEPIA2_ERR_SSM_TRIGGER_DATA_NOT_FOUND: Error.Sepia2Error.ValueType  # -7055
    """ "SSM: trigger data not found" """
    SEPIA2_ERR_SSM_CORRECTION_DATA_COMMAND_NOT_FOUND: Error.Sepia2Error.ValueType  # -7056
    """ "SSM: correction data command not found" """
    SEPIA2_ERR_SWS_SCALING_TABLES_NOT_FOUND: Error.Sepia2Error.ValueType  # -7101
    """ "SWS: scaling tables not found" """
    SEPIA2_ERR_SWS_ILLEGAL_HW_MODULETYPE: Error.Sepia2Error.ValueType  # -7102
    """ "SWS: illegal HW moduletype" """
    SEPIA2_ERR_SWS_MODULE_NOT_FUNCTIONAL: Error.Sepia2Error.ValueType  # -7103
    """ "SWS: module not functional" """
    SEPIA2_ERR_SWS_ILLEGAL_CENTER_WAVELENGTH: Error.Sepia2Error.ValueType  # -7104
    """ "SWS: illegal center wavelength" """
    SEPIA2_ERR_SWS_ILLEGAL_BANDWIDTH: Error.Sepia2Error.ValueType  # -7105
    """ "SWS: illegal bandwidth" """
    SEPIA2_ERR_SWS_VALUE_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -7106
    """ "SWS: value out of bounds" """
    SEPIA2_ERR_SWS_MODULE_BUSY: Error.Sepia2Error.ValueType  # -7107
    """ "SWS: module busy" """
    SEPIA2_ERR_SWS_FW_WRONG_COMPONENT_ANSWERING: Error.Sepia2Error.ValueType  # -7109
    """ "SWS FW: wrong component answering" """
    SEPIA2_ERR_SWS_FW_UNKNOWN_HW_MODULETYPE: Error.Sepia2Error.ValueType  # -7110
    """ "SWS FW: unknown HW moduletype" """
    SEPIA2_ERR_SWS_FW_OUT_OF_MEMORY: Error.Sepia2Error.ValueType  # -7111
    """ "SWS FW: out of memory" """
    SEPIA2_ERR_SWS_FW_VERSION_CONFLICT: Error.Sepia2Error.ValueType  # -7112
    """ "SWS FW: version conflict" """
    SEPIA2_ERR_SWS_FW_UPDATE_FAILED: Error.Sepia2Error.ValueType  # -7113
    """ "SWS FW: update failed" """
    SEPIA2_ERR_SWS_FW_CRC_CHECK_FAILED: Error.Sepia2Error.ValueType  # -7114
    """ "SWS FW: CRC check failed" """
    SEPIA2_ERR_SWS_FW_ERROR_ON_FLASH_DELETION: Error.Sepia2Error.ValueType  # -7115
    """ "SWS FW: error on flash deletion" """
    SEPIA2_ERR_SWS_FW_CALIBRATION_MODE_ERROR: Error.Sepia2Error.ValueType  # -7116
    """ "SWS FW: calibration mode error" """
    SEPIA2_ERR_SWS_FW_FUNCTION_NOT_IMPLEMENTED: Error.Sepia2Error.ValueType  # -7117
    """ "SWS FW: function not implemented" """
    SEPIA2_ERR_SWS_FW_WRONG_CALTABLE_ENTRY: Error.Sepia2Error.ValueType  # -7118
    """ "SWS FW: wrong calibration table entry" """
    SEPIA2_ERR_SWS_FW_INSUFFICIENT_CALTABLE_SIZE: Error.Sepia2Error.ValueType  # -7119
    """ "SWS FW: insufficient calibration table size" """
    SEPIA2_ERR_SWS_FW_FILE_OPEN_ERROR: Error.Sepia2Error.ValueType  # -7151
    """ "SWS FW: file open error" """
    SEPIA2_ERR_SWS_FW_FILE_READ_ERROR: Error.Sepia2Error.ValueType  # -7152
    """ "SWS FW: file read error" """
    SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_INIT_TIMEOUT: Error.Sepia2Error.ValueType  # -7201
    """ "SWS HW: module 0, all motors: init timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_PLAUSI_CHECK: Error.Sepia2Error.ValueType  # -7202
    """ "SWS HW: module 0, all motors: plausi check" """
    SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_DAC_SET_CURRENT: Error.Sepia2Error.ValueType  # -7203
    """ "SWS HW: module 0, all motors: DAC set current" """
    SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_TIMEOUT: Error.Sepia2Error.ValueType  # -7204
    """ "SWS HW: module 0, all motors: timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_FLASH_WRITE_ERROR: Error.Sepia2Error.ValueType  # -7205
    """ "SWS HW: module 0, all motors: flash write error" """
    SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -7206
    """ "SWS HW: module 0, all motors: out of bounds" """
    SEPIA2_ERR_SWS_HW_MODULE_0_I2C_FAILURE: Error.Sepia2Error.ValueType  # -7207
    """ "SWS HW: module 0: I2C failure" """
    SEPIA2_ERR_SWS_HW_MODULE_0_INIT_FAILURE: Error.Sepia2Error.ValueType  # -7208
    """ "SWS HW: module 0: init failure" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_DATA_NOT_FOUND: Error.Sepia2Error.ValueType  # -7210
    """ "SWS HW: module 0, motor 1: data not found" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_INIT_TIMEOUT: Error.Sepia2Error.ValueType  # -7211
    """ "SWS HW: module 0, motor 1: init timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_PLAUSI_CHECK: Error.Sepia2Error.ValueType  # -7212
    """ "SWS HW: module 0, motor 1: plausi check" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_DAC_SET_CURRENT: Error.Sepia2Error.ValueType  # -7213
    """ "SWS HW: module 0, motor 1: DAC set current" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_TIMEOUT: Error.Sepia2Error.ValueType  # -7214
    """ "SWS HW: module 0, motor 1: timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_FLASH_WRITE_ERROR: Error.Sepia2Error.ValueType  # -7215
    """ "SWS HW: module 0, motor 1: flash write error" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -7216
    """ "SWS HW: module 0, motor 1: out of bounds" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_DATA_NOT_FOUND: Error.Sepia2Error.ValueType  # -7220
    """ "SWS HW: module 0, motor 2: data not found" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_INIT_TIMEOUT: Error.Sepia2Error.ValueType  # -7221
    """ "SWS HW: module 0, motor 2: init timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_PLAUSI_CHECK: Error.Sepia2Error.ValueType  # -7222
    """ "SWS HW: module 0, motor 2: plausi check" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_DAC_SET_CURRENT: Error.Sepia2Error.ValueType  # -7223
    """ "SWS HW: module 0, motor 2: DAC set current" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_TIMEOUT: Error.Sepia2Error.ValueType  # -7224
    """ "SWS HW: module 0, motor 2: timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_FLASH_WRITE_ERROR: Error.Sepia2Error.ValueType  # -7225
    """ "SWS HW: module 0, motor 2: flash write error" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -7226
    """ "SWS HW: module 0, motor 2: out of bounds" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_DATA_NOT_FOUND: Error.Sepia2Error.ValueType  # -7230
    """ "SWS HW: module 0, motor 3: data not found" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_INIT_TIMEOUT: Error.Sepia2Error.ValueType  # -7231
    """ "SWS HW: module 0, motor 3: init timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_PLAUSI_CHECK: Error.Sepia2Error.ValueType  # -7232
    """ "SWS HW: module 0, motor 3: plausi check" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_DAC_SET_CURRENT: Error.Sepia2Error.ValueType  # -7233
    """ "SWS HW: module 0, motor 3: DAC set current" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_TIMEOUT: Error.Sepia2Error.ValueType  # -7234
    """ "SWS HW: module 0, motor 3: timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_FLASH_WRITE_ERROR: Error.Sepia2Error.ValueType  # -7235
    """ "SWS HW: module 0, motor 3: flash write error" """
    SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -7236
    """ "SWS HW: module 0, motor 3: out of bounds" """
    SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_INIT_TIMEOUT: Error.Sepia2Error.ValueType  # -7301
    """ "SWS HW: module 1, all motors: init timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_PLAUSI_CHECK: Error.Sepia2Error.ValueType  # -7302
    """ "SWS HW: module 1, all motors: plausi check" """
    SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_DAC_SET_CURRENT: Error.Sepia2Error.ValueType  # -7303
    """ "SWS HW: module 1, all motors: DAC set current" """
    SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_TIMEOUT: Error.Sepia2Error.ValueType  # -7304
    """ "SWS HW: module 1, all motors: timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_FLASH_WRITE_ERROR: Error.Sepia2Error.ValueType  # -7305
    """ "SWS HW: module 1, all motors: flash write error" """
    SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -7306
    """ "SWS HW: module 1, all motors: out of bounds" """
    SEPIA2_ERR_SWS_HW_MODULE_1_I2C_FAILURE: Error.Sepia2Error.ValueType  # -7307
    """ "SWS HW: module 1: I2C failure" """
    SEPIA2_ERR_SWS_HW_MODULE_1_INIT_FAILURE: Error.Sepia2Error.ValueType  # -7308
    """ "SWS HW: module 1: init failure" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_DATA_NOT_FOUND: Error.Sepia2Error.ValueType  # -7310
    """ "SWS HW: module 1, motor 1: data not found" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_INIT_TIMEOUT: Error.Sepia2Error.ValueType  # -7311
    """ "SWS HW: module 1, motor 1: init timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_PLAUSI_CHECK: Error.Sepia2Error.ValueType  # -7312
    """ "SWS HW: module 1, motor 1: plausi check" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_DAC_SET_CURRENT: Error.Sepia2Error.ValueType  # -7313
    """ "SWS HW: module 1, motor 1: DAC set current" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_TIMEOUT: Error.Sepia2Error.ValueType  # -7314
    """ "SWS HW: module 1, motor 1: timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_FLASH_WRITE_ERROR: Error.Sepia2Error.ValueType  # -7315
    """ "SWS HW: module 1, motor 1: flash write error" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -7316
    """ "SWS HW: module 1, motor 1: out of bounds" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_DATA_NOT_FOUND: Error.Sepia2Error.ValueType  # -7320
    """ "SWS HW: module 1, motor 2: data not found" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_INIT_TIMEOUT: Error.Sepia2Error.ValueType  # -7321
    """ "SWS HW: module 1, motor 2: init timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_PLAUSI_CHECK: Error.Sepia2Error.ValueType  # -7322
    """ "SWS HW: module 1, motor 2: plausi check" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_DAC_SET_CURRENT: Error.Sepia2Error.ValueType  # -7323
    """ "SWS HW: module 1, motor 2: DAC set current" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_TIMEOUT: Error.Sepia2Error.ValueType  # -7324
    """ "SWS HW: module 1, motor 2: timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_FLASH_WRITE_ERROR: Error.Sepia2Error.ValueType  # -7325
    """ "SWS HW: module 1, motor 2: flash write error" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -7326
    """ "SWS HW: module 1, motor 2: out of bounds" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_DATA_NOT_FOUND: Error.Sepia2Error.ValueType  # -7330
    """ "SWS HW: module 1, motor 3: data not found" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_INIT_TIMEOUT: Error.Sepia2Error.ValueType  # -7331
    """ "SWS HW: module 1, motor 3: init timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_PLAUSI_CHECK: Error.Sepia2Error.ValueType  # -7332
    """ "SWS HW: module 1, motor 3: plausi check" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_DAC_SET_CURRENT: Error.Sepia2Error.ValueType  # -7333
    """ "SWS HW: module 1, motor 3: DAC set current" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_TIMEOUT: Error.Sepia2Error.ValueType  # -7334
    """ "SWS HW: module 1, motor 3: timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_FLASH_WRITE_ERROR: Error.Sepia2Error.ValueType  # -7335
    """ "SWS HW: module 1, motor 3: flash write error" """
    SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -7336
    """ "SWS HW: module 1, motor 3: out of bounds" """
    SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_INIT_TIMEOUT: Error.Sepia2Error.ValueType  # -7401
    """ "SWS HW: module 2, all motors: init timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_PLAUSI_CHECK: Error.Sepia2Error.ValueType  # -7402
    """ "SWS HW: module 2, all motors: plausi check" """
    SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_DAC_SET_CURRENT: Error.Sepia2Error.ValueType  # -7403
    """ "SWS HW: module 2, all motors: DAC set current" """
    SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_TIMEOUT: Error.Sepia2Error.ValueType  # -7404
    """ "SWS HW: module 2, all motors: timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_FLASH_WRITE_ERROR: Error.Sepia2Error.ValueType  # -7405
    """ "SWS HW: module 2, all motors: flash write error" """
    SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -7406
    """ "SWS HW: module 2, all motors: out of bounds" """
    SEPIA2_ERR_SWS_HW_MODULE_2_I2C_FAILURE: Error.Sepia2Error.ValueType  # -7407
    """ "SWS HW: module 2: I2C failure" """
    SEPIA2_ERR_SWS_HW_MODULE_2_INIT_FAILURE: Error.Sepia2Error.ValueType  # -7408
    """ "SWS HW: module 2: init failure" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_DATA_NOT_FOUND: Error.Sepia2Error.ValueType  # -7410
    """ "SWS HW: module 2, motor 1: data not found" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_INIT_TIMEOUT: Error.Sepia2Error.ValueType  # -7411
    """ "SWS HW: module 2, motor 1: init timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_PLAUSI_CHECK: Error.Sepia2Error.ValueType  # -7412
    """ "SWS HW: module 2, motor 1: plausi check" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_DAC_SET_CURRENT: Error.Sepia2Error.ValueType  # -7413
    """ "SWS HW: module 2, motor 1: DAC set current" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_TIMEOUT: Error.Sepia2Error.ValueType  # -7414
    """ "SWS HW: module 2, motor 1: timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_FLASH_WRITE_ERROR: Error.Sepia2Error.ValueType  # -7415
    """ "SWS HW: module 2, motor 1: flash write error" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -7416
    """ "SWS HW: module 2, motor 1: out of bounds" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_DATA_NOT_FOUND: Error.Sepia2Error.ValueType  # -7420
    """ "SWS HW: module 2, motor 2: data not found" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_INIT_TIMEOUT: Error.Sepia2Error.ValueType  # -7421
    """ "SWS HW: module 2, motor 2: init timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_PLAUSI_CHECK: Error.Sepia2Error.ValueType  # -7422
    """ "SWS HW: module 2, motor 2: plausi check" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_DAC_SET_CURRENT: Error.Sepia2Error.ValueType  # -7423
    """ "SWS HW: module 2, motor 2: DAC set current" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_TIMEOUT: Error.Sepia2Error.ValueType  # -7424
    """ "SWS HW: module 2, motor 2: timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_FLASH_WRITE_ERROR: Error.Sepia2Error.ValueType  # -7425
    """ "SWS HW: module 2, motor 2: flash write error" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -7426
    """ "SWS HW: module 2, motor 2: out of bounds" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_DATA_NOT_FOUND: Error.Sepia2Error.ValueType  # -7430
    """ "SWS HW: module 2, motor 3: data not found" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_INIT_TIMEOUT: Error.Sepia2Error.ValueType  # -7431
    """ "SWS HW: module 2, motor 3: init timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_PLAUSI_CHECK: Error.Sepia2Error.ValueType  # -7432
    """ "SWS HW: module 2, motor 3: plausi check" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_DAC_SET_CURRENT: Error.Sepia2Error.ValueType  # -7433
    """ "SWS HW: module 2, motor 3: DAC set current" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_TIMEOUT: Error.Sepia2Error.ValueType  # -7434
    """ "SWS HW: module 2, motor 3: timeout" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_FLASH_WRITE_ERROR: Error.Sepia2Error.ValueType  # -7435
    """ "SWS HW: module 2, motor 3: flash write error" """
    SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_OUT_OF_BOUNDS: Error.Sepia2Error.ValueType  # -7436
    """ "SWS HW: module 2, motor 3: out of bounds" """
    SEPIA2_ERR_LIB_TOO_MANY_USB_HANDLES: Error.Sepia2Error.ValueType  # -9001
    """ "LIB: too many USB handles" """
    SEPIA2_ERR_LIB_ILLEGAL_DEVICE_INDEX: Error.Sepia2Error.ValueType  # -9002
    """ "LIB: illegal device index" """
    SEPIA2_ERR_LIB_USB_DEVICE_OPEN_ERROR: Error.Sepia2Error.ValueType  # -9003
    """ "LIB: USB device open error" """
    SEPIA2_ERR_LIB_USB_DEVICE_BUSY_OR_BLOCKED: Error.Sepia2Error.ValueType  # -9004
    """ "LIB: USB device busy or blocked" """
    SEPIA2_ERR_LIB_USB_DEVICE_ALREADY_OPENED: Error.Sepia2Error.ValueType  # -9005
    """ "LIB: USB device already opened" """
    SEPIA2_ERR_LIB_UNKNOWN_USB_HANDLE: Error.Sepia2Error.ValueType  # -9006
    """ "LIB: unknown USB handle" """
    SEPIA2_ERR_LIB_SCM_828_MODULE_NOT_FOUND: Error.Sepia2Error.ValueType  # -9007
    """ "LIB: SCM 828 module not found" """
    SEPIA2_ERR_LIB_ILLEGAL_SLOT_NUMBER: Error.Sepia2Error.ValueType  # -9008
    """ "LIB: illegal slot number" """
    SEPIA2_ERR_LIB_REFERENCED_SLOT_IS_NOT_IN_USE: Error.Sepia2Error.ValueType  # -9009
    """ "LIB: referenced slot is not in use" """
    SEPIA2_ERR_LIB_THIS_IS_NO_SCM_828_MODULE: Error.Sepia2Error.ValueType  # -9010
    """ "LIB: this is no SCM 828 module" """
    SEPIA2_ERR_LIB_THIS_IS_NO_SOM_828_MODULE: Error.Sepia2Error.ValueType  # -9011
    """ "LIB: this is no SOM 828 module" """
    SEPIA2_ERR_LIB_THIS_IS_NO_SLM_828_MODULE: Error.Sepia2Error.ValueType  # -9012
    """ "LIB: this is no SLM 828 module" """
    SEPIA2_ERR_LIB_THIS_IS_NO_SML_828_MODULE: Error.Sepia2Error.ValueType  # -9013
    """ "LIB: this is no SML 828 module" """
    SEPIA2_ERR_LIB_THIS_IS_NO_SWM_828_MODULE: Error.Sepia2Error.ValueType  # -9014
    """ "LIB: this is no SWM 828 module" """
    SEPIA2_ERR_LIB_THIS_IS_NO_SSM_MODULE: Error.Sepia2Error.ValueType  # -9015
    """ "LIB: this is no SSM module" """
    SEPIA2_ERR_LIB_THIS_IS_NO_SWS_MODULE: Error.Sepia2Error.ValueType  # -9016
    """ "LIB: this is no SWS module" """
    SEPIA2_ERR_LIB_THIS_IS_NO_SPM_MODULE: Error.Sepia2Error.ValueType  # -9017
    """ "LIB: this is no SPM module" """
    SEPIA2_ERR_LIB_THIS_IS_NO_LMP1: Error.Sepia2Error.ValueType  # -9018
    """ "LIB: this is no LMP1 (metermodule w. shuttercontrol)" """
    SEPIA2_ERR_LIB_THIS_IS_NO_SOM_828_D_MODULE: Error.Sepia2Error.ValueType  # -9019
    """ "LIB: this is no SOM 828 D module" """
    SEPIA2_ERR_LIB_NO_MAP_FOUND: Error.Sepia2Error.ValueType  # -9020
    """ "LIB: no map found" """
    SEPIA2_ERR_LIB_THIS_IS_NO_LMP8: Error.Sepia2Error.ValueType  # -9021
    """ "LIB: this is no LMP8 (eightfold metermodule)" """
    SEPIA2_ERR_LIB_THIS_IS_NO_VCL_828_MODULE: Error.Sepia2Error.ValueType  # -9022
    """ "LIB: this is no VCL 828 module" """
    SEPIA2_ERR_LIB_THIS_IS_NO_VUV_NOR_VIR_MODULE: Error.Sepia2Error.ValueType  # -9023
    """ "LIB: this is no VUV nor VIR module" """
    SEPIA2_ERR_LIB_THIS_IS_NO_PRI_MODULE: Error.Sepia2Error.ValueType  # -9024
    """ "LIB: this is no PRI module" """
    SEPIA2_ERR_LIB_DEVICE_CHANGED_RE_INITIALISE_USB_DEVICE_LIST: Error.Sepia2Error.ValueType  # -9025
    """ "LIB: device changed, re-initialise USB device list" """
    SEPIA2_ERR_LIB_INAPPROPRIATE_USB_DEVICE: Error.Sepia2Error.ValueType  # -9026
    """ "LIB: inappropriate USB device" """
    SEPIA2_ERR_LIB_WRONG_USB_DRIVER_VERSION: Error.Sepia2Error.ValueType  # -9090
    """ "LIB: wrong USB driver version" """
    SEPIA2_ERR_LIB_UNKNOWN_FUNCTION: Error.Sepia2Error.ValueType  # -9900
    """ "LIB: unknown function" """
    SEPIA2_ERR_LIB_ILLEGAL_PARAMETER_ON_FUNCTION_CALL: Error.Sepia2Error.ValueType  # -9910
    """ "LIB: illegal parameter on function call" """
    SEPIA2_ERR_LIB_UNKNOWN_ERROR_CODE: Error.Sepia2Error.ValueType  # -9999
    """ "LIB: unknown error code" """

    ERROR_FIELD_NUMBER: builtins.int
    error: global___Error.Sepia2Error.ValueType
    def __init__(
        self,
        *,
        error: global___Error.Sepia2Error.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_error", b"_error", "error", b"error"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_error", b"_error", "error", b"error"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_error", b"_error"]) -> typing.Literal["error"] | None: ...

global___Error = Error
